Class: Aws::EKS::Types::ActivateCertificateAuthorityResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_authorityTypes::CertificateAuthoritySummary

Summary information about the certificate authority that is being activated.



227
228
229
230
231
232
# File 'lib/aws-sdk-eks/types.rb', line 227

class ActivateCertificateAuthorityResponse < Struct.new(
  :update,
  :certificate_authority)
  SENSITIVE = []
  include Aws::Structure
end

#updateTypes::Update

An object representing the asynchronous update that promotes the certificate authority to be the cluster's signer.

Returns:



227
228
229
230
231
232
# File 'lib/aws-sdk-eks/types.rb', line 227

class ActivateCertificateAuthorityResponse < Struct.new(
  :update,
  :certificate_authority)
  SENSITIVE = []
  include Aws::Structure
end