Class: Aws::EKS::Types::ActiveCertificateAuthority

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Identifies the certificate authority that is currently signing certificates for the cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activated_byString

The entity that activated the current signing certificate authority, either CUSTOMER or EKS.

Returns:

  • (String)


249
250
251
252
253
254
# File 'lib/aws-sdk-eks/types.rb', line 249

class ActiveCertificateAuthority < Struct.new(
  :id,
  :activated_by)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the certificate authority that is currently signing certificates for the cluster.

Returns:

  • (String)


249
250
251
252
253
254
# File 'lib/aws-sdk-eks/types.rb', line 249

class ActiveCertificateAuthority < Struct.new(
  :id,
  :activated_by)
  SENSITIVE = []
  include Aws::Structure
end