Class: Aws::EKS::Types::AddonNamespaceConfigResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The namespace configuration response object containing information about the namespace where an addon is installed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#namespaceString

The name of the Kubernetes namespace where the addon is installed.

Returns:

  • (String)


498
499
500
501
502
# File 'lib/aws-sdk-eks/types.rb', line 498

class AddonNamespaceConfigResponse < Struct.new(
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end