Class: Aws::EKS::Types::CancelUpdateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::CancelUpdateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#name ⇒ String
The name of the Amazon EKS cluster associated with the update.
-
#update_id ⇒ String
The ID of the update to cancel.
Instance Attribute Details
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-eks/types.rb', line 973 class CancelUpdateRequest < Struct.new( :name, :update_id, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon EKS cluster associated with the update.
973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-eks/types.rb', line 973 class CancelUpdateRequest < Struct.new( :name, :update_id, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#update_id ⇒ String
The ID of the update to cancel.
973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-eks/types.rb', line 973 class CancelUpdateRequest < Struct.new( :name, :update_id, :client_request_token) SENSITIVE = [] include Aws::Structure end |