Class: Aws::EKS::Types::CapabilitySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

A summary of a capability, containing basic information without the full configuration details. This is returned by the ListCapabilities operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the capability.

Returns:

  • (String)


1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/aws-sdk-eks/types.rb', line 1341

class CapabilitySummary < Struct.new(
  :capability_name,
  :arn,
  :type,
  :status,
  :version,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#capability_name ⇒ String

The unique name of the capability within the cluster.

Returns:

  • (String)


1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/aws-sdk-eks/types.rb', line 1341

class CapabilitySummary < Struct.new(
  :capability_name,
  :arn,
  :type,
  :status,
  :version,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The Unix epoch timestamp in seconds for when the capability was created.

Returns:

  • (Time)


1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/aws-sdk-eks/types.rb', line 1341

class CapabilitySummary < Struct.new(
  :capability_name,
  :arn,
  :type,
  :status,
  :version,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#modified_at ⇒ Time

The Unix epoch timestamp in seconds for when the capability was last modified.

Returns:

  • (Time)


1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/aws-sdk-eks/types.rb', line 1341

class CapabilitySummary < Struct.new(
  :capability_name,
  :arn,
  :type,
  :status,
  :version,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the capability.

Returns:

  • (String)


1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/aws-sdk-eks/types.rb', line 1341

class CapabilitySummary < Struct.new(
  :capability_name,
  :arn,
  :type,
  :status,
  :version,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of capability. Valid values are ACK, ARGOCD, or KRO.

Returns:

  • (String)


1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/aws-sdk-eks/types.rb', line 1341

class CapabilitySummary < Struct.new(
  :capability_name,
  :arn,
  :type,
  :status,
  :version,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The version of the capability software that is currently running.

Returns:

  • (String)


1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/aws-sdk-eks/types.rb', line 1341

class CapabilitySummary < Struct.new(
  :capability_name,
  :arn,
  :type,
  :status,
  :version,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end