Class: Aws::EKS::Types::Certificate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

An object representing the certificate-authority-data for your cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activeTypes::ActiveCertificateAuthority

An object identifying the certificate authority that is currently signing certificates for the cluster.



1355
1356
1357
1358
1359
1360
# File 'lib/aws-sdk-eks/types.rb', line 1355

class Certificate < Struct.new(
  :data,
  :active)
  SENSITIVE = []
  include Aws::Structure
end

#dataString

The Base64-encoded certificate data required to communicate with your cluster. Add this to the certificate-authority-data section of the kubeconfig file for your cluster.

Returns:

  • (String)


1355
1356
1357
1358
1359
1360
# File 'lib/aws-sdk-eks/types.rb', line 1355

class Certificate < Struct.new(
  :data,
  :active)
  SENSITIVE = []
  include Aws::Structure
end