Class: Aws::EKS::Types::CertificateAuthorityScheduledEvents

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The scheduled events during which Amazon EKS may automatically activate a certificate authority, computed from its validity period. These events help ensure that a cluster's signing certificate authority is rotated before its certificate expires.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#final_auto_activationTime

The Unix epoch timestamp in seconds by which Amazon EKS will automatically activate this certificate authority if you haven't already activated it.

Returns:

  • (Time)


1468
1469
1470
1471
1472
1473
# File 'lib/aws-sdk-eks/types.rb', line 1468

class CertificateAuthorityScheduledEvents < Struct.new(
  :first_auto_activation,
  :final_auto_activation)
  SENSITIVE = []
  include Aws::Structure
end

#first_auto_activationTime

The earliest Unix epoch timestamp in seconds at which Amazon EKS may automatically activate this certificate authority.

Returns:

  • (Time)


1468
1469
1470
1471
1472
1473
# File 'lib/aws-sdk-eks/types.rb', line 1468

class CertificateAuthorityScheduledEvents < Struct.new(
  :first_auto_activation,
  :final_auto_activation)
  SENSITIVE = []
  include Aws::Structure
end