Class: Aws::EKS::Types::CertificateAuthoritySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Summary information about a certificate authority (CA) for an Amazon EKS cluster, returned by ListCertificateAuthorities and the certificate-authority write operations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activated_atTime

The Unix epoch timestamp in seconds for when the certificate authority was last activated. This value is absent if the certificate authority has never been activated.

Returns:

  • (Time)


1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
# File 'lib/aws-sdk-eks/types.rb', line 1520

class CertificateAuthoritySummary < Struct.new(
  :id,
  :created_at,
  :created_by,
  :activated_at,
  :activated_by,
  :signing_status,
  :distribution_status)
  SENSITIVE = []
  include Aws::Structure
end

#activated_byString

The entity that most recently activated the certificate authority, either CUSTOMER or EKS.

Returns:

  • (String)


1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
# File 'lib/aws-sdk-eks/types.rb', line 1520

class CertificateAuthoritySummary < Struct.new(
  :id,
  :created_at,
  :created_by,
  :activated_at,
  :activated_by,
  :signing_status,
  :distribution_status)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The Unix epoch timestamp in seconds for when the certificate authority was created.

Returns:

  • (Time)


1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
# File 'lib/aws-sdk-eks/types.rb', line 1520

class CertificateAuthoritySummary < Struct.new(
  :id,
  :created_at,
  :created_by,
  :activated_at,
  :activated_by,
  :signing_status,
  :distribution_status)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The entity that created the certificate authority, either CUSTOMER or EKS.

Returns:

  • (String)


1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
# File 'lib/aws-sdk-eks/types.rb', line 1520

class CertificateAuthoritySummary < Struct.new(
  :id,
  :created_at,
  :created_by,
  :activated_at,
  :activated_by,
  :signing_status,
  :distribution_status)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_statusString

The distribution status of the certificate authority: IN_PROGRESS, COMPLETE, FAILED, or DELETING.

Returns:

  • (String)


1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
# File 'lib/aws-sdk-eks/types.rb', line 1520

class CertificateAuthoritySummary < Struct.new(
  :id,
  :created_at,
  :created_by,
  :activated_at,
  :activated_by,
  :signing_status,
  :distribution_status)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the certificate authority.

Returns:

  • (String)


1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
# File 'lib/aws-sdk-eks/types.rb', line 1520

class CertificateAuthoritySummary < Struct.new(
  :id,
  :created_at,
  :created_by,
  :activated_at,
  :activated_by,
  :signing_status,
  :distribution_status)
  SENSITIVE = []
  include Aws::Structure
end

#signing_statusString

The signing status of the certificate authority: IN_USE, ACTIVATING, or NOT_USED.

Returns:

  • (String)


1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
# File 'lib/aws-sdk-eks/types.rb', line 1520

class CertificateAuthoritySummary < Struct.new(
  :id,
  :created_at,
  :created_by,
  :activated_at,
  :activated_by,
  :signing_status,
  :distribution_status)
  SENSITIVE = []
  include Aws::Structure
end