Class: Aws::EKS::Types::CertificateAuthorityValidity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The validity period of a certificate authority's certificate.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#not_afterTime

The Unix epoch timestamp in seconds for the end of the certificate authority's validity period.

Returns:

  • (Time)


1546
1547
1548
1549
1550
1551
# File 'lib/aws-sdk-eks/types.rb', line 1546

class CertificateAuthorityValidity < Struct.new(
  :not_before,
  :not_after)
  SENSITIVE = []
  include Aws::Structure
end

#not_beforeTime

The Unix epoch timestamp in seconds for the start of the certificate authority's validity period.

Returns:

  • (Time)


1546
1547
1548
1549
1550
1551
# File 'lib/aws-sdk-eks/types.rb', line 1546

class CertificateAuthorityValidity < Struct.new(
  :not_before,
  :not_after)
  SENSITIVE = []
  include Aws::Structure
end