Class: Aws::EKS::Types::ClusterVersionInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ClusterVersionInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Contains details about a specific EKS cluster version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_type ⇒ String
The type of cluster this version is for.
-
#cluster_version ⇒ String
The Kubernetes version for the cluster.
-
#default_platform_version ⇒ String
Default platform version for this Kubernetes version.
-
#default_version ⇒ Boolean
Indicates if this is a default version.
-
#end_of_extended_support_date ⇒ Time
Date when extended support ends for this version.
-
#end_of_standard_support_date ⇒ Time
Date when standard support ends for this version.
-
#kubernetes_patch_version ⇒ String
The patch version of Kubernetes for this cluster version.
-
#release_date ⇒ Time
The release date of this cluster version.
-
#status ⇒ String
This field is deprecated.
-
#version_status ⇒ String
Current status of this cluster version.
Instance Attribute Details
#cluster_type ⇒ String
The type of cluster this version is for.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |
#cluster_version ⇒ String
The Kubernetes version for the cluster.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |
#default_platform_version ⇒ String
Default platform version for this Kubernetes version.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |
#default_version ⇒ Boolean
Indicates if this is a default version.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |
#end_of_extended_support_date ⇒ Time
Date when extended support ends for this version.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |
#end_of_standard_support_date ⇒ Time
Date when standard support ends for this version.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |
#kubernetes_patch_version ⇒ String
The patch version of Kubernetes for this cluster version.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |
#release_date ⇒ Time
The release date of this cluster version.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
This field is deprecated. Use versionStatus instead, as that field
matches for input and output of this action.
Current status of this cluster version.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |
#version_status ⇒ String
Current status of this cluster version.
1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-eks/types.rb', line 1633 class ClusterVersionInformation < Struct.new( :cluster_version, :cluster_type, :default_platform_version, :default_version, :release_date, :end_of_standard_support_date, :end_of_extended_support_date, :status, :version_status, :kubernetes_patch_version) SENSITIVE = [] include Aws::Structure end |