Class: Aws::EKS::Types::ControlPlanePlacementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The placement configuration for all the control plane instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see Capacity considerations in the Amazon EKS User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#group_nameString

The name of the placement group for the Kubernetes control plane instances. This setting can't be changed after cluster creation.

Returns:

  • (String)


1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-eks/types.rb', line 1882

class ControlPlanePlacementRequest < Struct.new(
  :group_name,
  :spread_level)
  SENSITIVE = []
  include Aws::Structure
end

#spread_levelString

Optional parameter to specify the placement group spread level for control plane instances. If not provided, Amazon EKS will deploy control plane instances without a placement group.

Returns:

  • (String)


1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-eks/types.rb', line 1882

class ControlPlanePlacementRequest < Struct.new(
  :group_name,
  :spread_level)
  SENSITIVE = []
  include Aws::Structure
end