Class: Aws::EKS::Types::ControlPlanePlacementResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ControlPlanePlacementResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The placement configuration for all the control plane instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see [Capacity considerations] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/eks-outposts-capacity-considerations.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_name ⇒ String
The name of the placement group for the Kubernetes control plane instances.
-
#spread_level ⇒ String
The spread level used with the placement group for control plane instances on your local Amazon EKS cluster on Amazon Web Services Outposts.
Instance Attribute Details
#group_name ⇒ String
The name of the placement group for the Kubernetes control plane instances.
1785 1786 1787 1788 1789 1790 |
# File 'lib/aws-sdk-eks/types.rb', line 1785 class ControlPlanePlacementResponse < Struct.new( :group_name, :spread_level) SENSITIVE = [] include Aws::Structure end |
#spread_level ⇒ String
The spread level used with the placement group for control plane instances on your local Amazon EKS cluster on Amazon Web Services Outposts.
1785 1786 1787 1788 1789 1790 |
# File 'lib/aws-sdk-eks/types.rb', line 1785 class ControlPlanePlacementResponse < Struct.new( :group_name, :spread_level) SENSITIVE = [] include Aws::Structure end |