Class: Aws::EKS::Types::CreateCertificateAuthorityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2682
2683
2684
2685
2686
2687
# File 'lib/aws-sdk-eks/types.rb', line 2682

class CreateCertificateAuthorityRequest < Struct.new(
  :cluster_name,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The name of your cluster.

Returns:

  • (String)


2682
2683
2684
2685
2686
2687
# File 'lib/aws-sdk-eks/types.rb', line 2682

class CreateCertificateAuthorityRequest < Struct.new(
  :cluster_name,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end