Class: Aws::EKS::Types::CreateCertificateAuthorityResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_authorityTypes::CertificateAuthoritySummary

Summary information about the certificate authority that was created, including its ID and initial signing and distribution status.



2702
2703
2704
2705
2706
2707
# File 'lib/aws-sdk-eks/types.rb', line 2702

class CreateCertificateAuthorityResponse < Struct.new(
  :update,
  :certificate_authority)
  SENSITIVE = []
  include Aws::Structure
end

#updateTypes::Update

An object representing the asynchronous update that adds the certificate authority to the cluster's trust bundle.

Returns:



2702
2703
2704
2705
2706
2707
# File 'lib/aws-sdk-eks/types.rb', line 2702

class CreateCertificateAuthorityResponse < Struct.new(
  :update,
  :certificate_authority)
  SENSITIVE = []
  include Aws::Structure
end