Class: Aws::EKS::Types::CreateNodegroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::CreateNodegroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ami_type ⇒ String
The AMI type for your node group.
-
#capacity_type ⇒ String
The capacity type for your node group.
-
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_name ⇒ String
The name of your cluster.
-
#disk_size ⇒ Integer
The root device disk size (in GiB) for your node group instances.
-
#instance_types ⇒ Array<String>
Specify the instance types for a node group.
-
#labels ⇒ Hash<String,String>
The Kubernetes
labelsto apply to the nodes in the node group when they are created. -
#launch_template ⇒ Types::LaunchTemplateSpecification
An object representing a node group’s launch template specification.
-
#node_repair_config ⇒ Types::NodeRepairConfig
The node auto repair configuration for the node group.
-
#node_role ⇒ String
The Amazon Resource Name (ARN) of the IAM role to associate with your node group.
-
#nodegroup_name ⇒ String
The unique name to give your node group.
-
#release_version ⇒ String
The AMI version of the Amazon EKS optimized AMI to use with your node group.
-
#remote_access ⇒ Types::RemoteAccessConfig
The remote access configuration to use with your node group.
-
#scaling_config ⇒ Types::NodegroupScalingConfig
The scaling configuration details for the Auto Scaling group that is created for your node group.
-
#subnets ⇒ Array<String>
The subnets to use for the Auto Scaling group that is created for your node group.
-
#tags ⇒ Hash<String,String>
Metadata that assists with categorization and organization.
-
#taints ⇒ Array<Types::Taint>
The Kubernetes taints to be applied to the nodes in the node group.
-
#update_config ⇒ Types::NodegroupUpdateConfig
The node group update configuration.
-
#version ⇒ String
The Kubernetes version to use for your managed nodes.
Instance Attribute Details
#ami_type ⇒ String
The AMI type for your node group. If you specify launchTemplate, and your launch template uses a custom AMI, then don’t specify amiType, or the node group deployment will fail. If your launch template uses a Windows custom AMI, then add eks:kube-proxy-windows to your Windows nodes rolearn in the aws-auth ConfigMap. For more information about using launch templates with Amazon EKS, see [Customizing managed nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#capacity_type ⇒ String
The capacity type for your node group.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of your cluster.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#disk_size ⇒ Integer
The root device disk size (in GiB) for your node group instances. The default disk size is 20 GiB for Linux and Bottlerocket. The default disk size is 50 GiB for Windows. If you specify launchTemplate, then don’t specify diskSize, or the node group deployment will fail. For more information about using launch templates with Amazon EKS, see [Customizing managed nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#instance_types ⇒ Array<String>
Specify the instance types for a node group. If you specify a GPU instance type, make sure to also specify an applicable GPU AMI type with the amiType parameter. If you specify launchTemplate, then you can specify zero or one instance type in your launch template or you can specify 0-20 instance types for instanceTypes. If however, you specify an instance type in your launch template and specify any instanceTypes, the node group deployment will fail. If you don’t specify an instance type in a launch template or for instanceTypes, then t3.medium is used, by default. If you specify Spot for capacityType, then we recommend specifying multiple values for instanceTypes. For more information, see
- Managed node group capacity types][1
-
and [Customizing managed
nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/managed-node-groups.html#managed-node-group-capacity-types [2]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#labels ⇒ Hash<String,String>
The Kubernetes labels to apply to the nodes in the node group when they are created.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#launch_template ⇒ Types::LaunchTemplateSpecification
An object representing a node group’s launch template specification. When using this object, don’t directly specify instanceTypes, diskSize, or remoteAccess. Make sure that the launch template meets the requirements in launchTemplateSpecification. Also refer to [Customizing managed nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#node_repair_config ⇒ Types::NodeRepairConfig
The node auto repair configuration for the node group.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#node_role ⇒ String
The Amazon Resource Name (ARN) of the IAM role to associate with your node group. The Amazon EKS worker node kubelet daemon makes calls to Amazon Web Services APIs on your behalf. Nodes receive permissions for these API calls through an IAM instance profile and associated policies. Before you can launch nodes and register them into a cluster, you must create an IAM role for those nodes to use when they are launched. For more information, see [Amazon EKS node IAM role] in the Amazon EKS User Guide . If you specify launchTemplate, then don’t specify ‘ IamInstanceProfile ` in your launch template, or the node group deployment will fail. For more information about using launch templates with Amazon EKS, see
- Customizing managed nodes with launch templates][2
-
in the *Amazon
EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/create-node-role.html [2]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#nodegroup_name ⇒ String
The unique name to give your node group.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#release_version ⇒ String
The AMI version of the Amazon EKS optimized AMI to use with your node group. By default, the latest available AMI version for the node group’s current Kubernetes version is used. For information about Linux versions, see [Amazon EKS optimized Amazon Linux AMI versions] in the *Amazon EKS User Guide*. Amazon EKS managed node groups support the November 2022 and later releases of the Windows AMIs. For information about Windows versions, see [Amazon EKS optimized Windows AMI versions] in the *Amazon EKS User Guide*.
If you specify launchTemplate, and your launch template uses a custom AMI, then don’t specify releaseVersion, or the node group deployment will fail. For more information about using launch templates with Amazon EKS, see [Customizing managed nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/eks-linux-ami-versions.html [2]: docs.aws.amazon.com/eks/latest/userguide/eks-ami-versions-windows.html [3]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#remote_access ⇒ Types::RemoteAccessConfig
The remote access configuration to use with your node group. For Linux, the protocol is SSH. For Windows, the protocol is RDP. If you specify launchTemplate, then don’t specify remoteAccess, or the node group deployment will fail. For more information about using launch templates with Amazon EKS, see [Customizing managed nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#scaling_config ⇒ Types::NodegroupScalingConfig
The scaling configuration details for the Auto Scaling group that is created for your node group.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<String>
The subnets to use for the Auto Scaling group that is created for your node group. If you specify launchTemplate, then don’t specify ‘ SubnetId ` in your launch template, or the node group deployment will fail. For more information about using launch templates with Amazon EKS, see [Customizing managed nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata that assists with categorization and organization. Each tag consists of a key and an optional value. You define both. Tags don’t propagate to any other cluster or Amazon Web Services resources.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#taints ⇒ Array<Types::Taint>
The Kubernetes taints to be applied to the nodes in the node group. For more information, see [Node taints on managed node groups].
[1]: docs.aws.amazon.com/eks/latest/userguide/node-taints-managed-node-groups.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#update_config ⇒ Types::NodegroupUpdateConfig
The node group update configuration.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The Kubernetes version to use for your managed nodes. By default, the Kubernetes version of the cluster is used, and this is the only accepted specified value. If you specify launchTemplate, and your launch template uses a custom AMI, then don’t specify version, or the node group deployment will fail. For more information about using launch templates with Amazon EKS, see [Customizing managed nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-eks/types.rb', line 2061 class CreateNodegroupRequest < Struct.new( :cluster_name, :nodegroup_name, :scaling_config, :disk_size, :subnets, :instance_types, :ami_type, :remote_access, :node_role, :labels, :taints, :tags, :client_request_token, :launch_template, :update_config, :node_repair_config, :capacity_type, :version, :release_version) SENSITIVE = [] include Aws::Structure end |