Class: Aws::EKS::Types::DeleteCertificateAuthorityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_authority_idString

The ID of the certificate authority to delete. You can't delete the certificate authority that's currently signing certificates for the cluster.

Returns:

  • (String)


3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-eks/types.rb', line 3623

class DeleteCertificateAuthorityRequest < Struct.new(
  :cluster_name,
  :certificate_authority_id,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_request_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-eks/types.rb', line 3623

class DeleteCertificateAuthorityRequest < Struct.new(
  :cluster_name,
  :certificate_authority_id,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The name of your cluster.

Returns:

  • (String)


3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-eks/types.rb', line 3623

class DeleteCertificateAuthorityRequest < Struct.new(
  :cluster_name,
  :certificate_authority_id,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end