Class: Aws::EKS::Types::DescribeAddonConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addon_name ⇒ String

The name of the add-on.

Returns:

  • (String)


3939
3940
3941
3942
3943
3944
3945
3946
# File 'lib/aws-sdk-eks/types.rb', line 3939

class DescribeAddonConfigurationResponse < Struct.new(
  :addon_name,
  :addon_version,
  :configuration_schema,
  :pod_identity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#addon_version ⇒ String

The version of the add-on. The version must match one of the versions returned by DescribeAddonVersions .

Returns:

  • (String)


3939
3940
3941
3942
3943
3944
3945
3946
# File 'lib/aws-sdk-eks/types.rb', line 3939

class DescribeAddonConfigurationResponse < Struct.new(
  :addon_name,
  :addon_version,
  :configuration_schema,
  :pod_identity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_schema ⇒ String

A JSON schema that's used to validate the configuration values you provide when an add-on is created or updated.

Returns:

  • (String)


3939
3940
3941
3942
3943
3944
3945
3946
# File 'lib/aws-sdk-eks/types.rb', line 3939

class DescribeAddonConfigurationResponse < Struct.new(
  :addon_name,
  :addon_version,
  :configuration_schema,
  :pod_identity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pod_identity_configuration ⇒ Array<Types::AddonPodIdentityConfiguration>

The Kubernetes service account name used by the add-on, and any suggested IAM policies. Use this information to create an IAM Role for the add-on.



3939
3940
3941
3942
3943
3944
3945
3946
# File 'lib/aws-sdk-eks/types.rb', line 3939

class DescribeAddonConfigurationResponse < Struct.new(
  :addon_name,
  :addon_version,
  :configuration_schema,
  :pod_identity_configuration)
  SENSITIVE = []
  include Aws::Structure
end