Class: Aws::EKS::Types::DescribeAddonVersionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addonsArray<Types::AddonInfo>

The list of available versions with Kubernetes version compatibility and other properties.

Returns:



4060
4061
4062
4063
4064
4065
# File 'lib/aws-sdk-eks/types.rb', line 4060

class DescribeAddonVersionsResponse < Struct.new(
  :addons,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value to include in a future DescribeAddonVersions request. When the results of a DescribeAddonVersions request exceed maxResults, you can use this value to retrieve the next page of results. This value is null when there are no more results to return.

This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


4060
4061
4062
4063
4064
4065
# File 'lib/aws-sdk-eks/types.rb', line 4060

class DescribeAddonVersionsResponse < Struct.new(
  :addons,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end