Class: Aws::EKS::Types::DescribeCertificateAuthorityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::DescribeCertificateAuthorityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_authority ⇒ Types::CertificateAuthority
An object containing detailed information about the certificate authority.
Instance Attribute Details
#certificate_authority ⇒ Types::CertificateAuthority
An object containing detailed information about the certificate authority.
4124 4125 4126 4127 4128 |
# File 'lib/aws-sdk-eks/types.rb', line 4124 class DescribeCertificateAuthorityResponse < Struct.new( :certificate_authority) SENSITIVE = [] include Aws::Structure end |