Class: Aws::EKS::Types::EksAnywhereSubscription
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::EksAnywhereSubscription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
An EKS Anywhere subscription authorizing the customer to support for licensed clusters and access to EKS Anywhere Curated Packages.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the subscription.
-
#auto_renew ⇒ Boolean
A boolean indicating whether or not a subscription will auto renew when it expires.
-
#created_at ⇒ Time
The Unix timestamp in seconds for when the subscription was created.
-
#effective_date ⇒ Time
The Unix timestamp in seconds for when the subscription is effective.
-
#expiration_date ⇒ Time
The Unix timestamp in seconds for when the subscription will expire or auto renew, depending on the auto renew configuration of the subscription object.
-
#id ⇒ String
UUID identifying a subscription.
-
#license_arns ⇒ Array<String>
Amazon Web Services License Manager ARN associated with the subscription.
-
#license_quantity ⇒ Integer
The number of licenses included in a subscription.
-
#license_type ⇒ String
The type of licenses included in the subscription.
-
#licenses ⇒ Array<Types::License>
Includes all of the claims in the license token necessary to validate the license for extended support.
-
#status ⇒ String
The status of a subscription.
-
#tags ⇒ Hash<String,String>
The metadata for a subscription to assist with categorization and organization.
-
#term ⇒ Types::EksAnywhereSubscriptionTerm
An EksAnywhereSubscriptionTerm object.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the subscription.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#auto_renew ⇒ Boolean
A boolean indicating whether or not a subscription will auto renew when it expires.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The Unix timestamp in seconds for when the subscription was created.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#effective_date ⇒ Time
The Unix timestamp in seconds for when the subscription is effective.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#expiration_date ⇒ Time
The Unix timestamp in seconds for when the subscription will expire or auto renew, depending on the auto renew configuration of the subscription object.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
UUID identifying a subscription.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#license_arns ⇒ Array<String>
Amazon Web Services License Manager ARN associated with the subscription.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#license_quantity ⇒ Integer
The number of licenses included in a subscription. Valid values are between 1 and 100.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#license_type ⇒ String
The type of licenses included in the subscription. Valid value is CLUSTER. With the CLUSTER license type, each license covers support for a single EKS Anywhere cluster.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#licenses ⇒ Array<Types::License>
Includes all of the claims in the license token necessary to validate the license for extended support.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of a subscription.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The metadata for a subscription to assist with categorization and organization. Each tag consists of a key and an optional value. Subscription tags do not propagate to any other resources associated with the subscription.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |
#term ⇒ Types::EksAnywhereSubscriptionTerm
An EksAnywhereSubscriptionTerm object.
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-eks/types.rb', line 4272 class EksAnywhereSubscription < Struct.new( :id, :arn, :created_at, :effective_date, :expiration_date, :license_quantity, :license_type, :term, :status, :auto_renew, :license_arns, :licenses, :tags) SENSITIVE = [] include Aws::Structure end |