Class: Aws::EKS::Types::EtcdPlacementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::EtcdPlacementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The placement configuration for the etcd instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see Capacity considerations in the Amazon EKS User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#spread_level ⇒ String
Optional parameter to specify the placement group spread level for etcd instances.
Instance Attribute Details
#spread_level ⇒ String
Optional parameter to specify the placement group spread level for etcd instances. If not provided, Amazon EKS will deploy etcd instances without a placement group.
4418 4419 4420 4421 4422 |
# File 'lib/aws-sdk-eks/types.rb', line 4418 class EtcdPlacementRequest < Struct.new( :spread_level) SENSITIVE = [] include Aws::Structure end |