Class: Aws::EKS::Types::EtcdPlacementResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The placement configuration for the etcd instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see Capacity considerations in the Amazon EKS User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#spread_levelString

The spread level used with the placement group for etcd instances on your local Amazon EKS cluster on Amazon Web Services Outposts.

Returns:

  • (String)


4825
4826
4827
4828
4829
# File 'lib/aws-sdk-eks/types.rb', line 4825

class EtcdPlacementResponse < Struct.new(
  :spread_level)
  SENSITIVE = []
  include Aws::Structure
end