Class: Aws::EKS::Types::FargateProfile

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

An object representing an Fargate profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_nameString

The name of your cluster.

Returns:

  • (String)


4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The Unix epoch timestamp at object creation.

Returns:

  • (Time)


4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end

#fargate_profile_arnString

The full Amazon Resource Name (ARN) of the Fargate profile.

Returns:

  • (String)


4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end

#fargate_profile_nameString

The name of the Fargate profile.

Returns:

  • (String)


4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end

#healthTypes::FargateProfileHealth

The health status of the Fargate profile. If there are issues with your Fargate profile's health, they are listed here.



4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end

#pod_execution_role_arnString

The Amazon Resource Name (ARN) of the Pod execution role to use for any Pod that matches the selectors in the Fargate profile. For more information, see Pod execution role in the Amazon EKS User Guide.

Returns:

  • (String)


4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end

#selectorsArray<Types::FargateProfileSelector>

The selectors to match for a Pod to use this Fargate profile.

Returns:



4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the Fargate profile.

Returns:

  • (String)


4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end

#subnetsArray<String>

The IDs of subnets to launch a Pod into.

Returns:

  • (Array<String>)


4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Metadata that assists with categorization and organization. Each tag consists of a key and an optional value. You define both. Tags don't propagate to any other cluster or Amazon Web Services resources.

Returns:

  • (Hash<String,String>)


4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-eks/types.rb', line 4886

class FargateProfile < Struct.new(
  :fargate_profile_name,
  :fargate_profile_arn,
  :cluster_name,
  :created_at,
  :pod_execution_role_arn,
  :subnets,
  :selectors,
  :status,
  :tags,
  :health)
  SENSITIVE = []
  include Aws::Structure
end