Class: Aws::EKS::Types::FargateProfileSelector

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

An object representing an Fargate profile selector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#labelsHash<String,String>

The Kubernetes labels that the selector should match. A pod must contain all of the labels that are specified in the selector for it to be considered a match.

Returns:

  • (Hash<String,String>)


4569
4570
4571
4572
4573
4574
# File 'lib/aws-sdk-eks/types.rb', line 4569

class FargateProfileSelector < Struct.new(
  :namespace,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The Kubernetes namespace that the selector should match.

Returns:

  • (String)


4569
4570
4571
4572
4573
4574
# File 'lib/aws-sdk-eks/types.rb', line 4569

class FargateProfileSelector < Struct.new(
  :namespace,
  :labels)
  SENSITIVE = []
  include Aws::Structure
end