Class: Aws::EKS::Types::HorizontalPodAutoscalerControllerConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The horizontal pod autoscaler controller configuration for the Kubernetes controller manager.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#horizontal_pod_autoscaler_sync_periodString

The interval between each sync of the horizontal pod autoscaler. Valid values are single-unit durations such as 15s or 1m.

Returns:

  • (String)


4586
4587
4588
4589
4590
# File 'lib/aws-sdk-eks/types.rb', line 4586

class HorizontalPodAutoscalerControllerConfigRequest < Struct.new(
  :horizontal_pod_autoscaler_sync_period)
  SENSITIVE = []
  include Aws::Structure
end