Class: Aws::EKS::Types::HorizontalPodAutoscalerControllerConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::HorizontalPodAutoscalerControllerConfigResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The horizontal pod autoscaler controller configuration for the Kubernetes controller manager.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#horizontal_pod_autoscaler_sync_period ⇒ String
The interval between each sync of the horizontal pod autoscaler.
Instance Attribute Details
#horizontal_pod_autoscaler_sync_period ⇒ String
The interval between each sync of the horizontal pod autoscaler.
4601 4602 4603 4604 4605 |
# File 'lib/aws-sdk-eks/types.rb', line 4601 class HorizontalPodAutoscalerControllerConfigResponse < Struct.new( :horizontal_pod_autoscaler_sync_period) SENSITIVE = [] include Aws::Structure end |