Class: Aws::EKS::Types::Insight
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::Insight
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
A check that provides recommendations to remedy potential upgrade-impacting issues.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_info ⇒ Hash<String,String>
Links to sources that provide additional context on the insight.
-
#category ⇒ String
The category of the insight.
-
#category_specific_summary ⇒ Types::InsightCategorySpecificSummary
Summary information that relates to the category of the insight.
-
#description ⇒ String
The description of the insight which includes alert criteria, remediation recommendation, and additional resources (contains Markdown).
-
#id ⇒ String
The ID of the insight.
-
#insight_status ⇒ Types::InsightStatus
An object containing more detail on the status of the insight resource.
-
#kubernetes_version ⇒ String
The Kubernetes minor version associated with an insight if applicable.
-
#last_refresh_time ⇒ Time
The time Amazon EKS last successfully completed a refresh of this insight check on the cluster.
-
#last_transition_time ⇒ Time
The time the status of the insight last changed.
-
#name ⇒ String
The name of the insight.
-
#recommendation ⇒ String
A summary of how to remediate the finding of this insight if applicable.
-
#resources ⇒ Array<Types::InsightResourceDetail>
The details about each resource listed in the insight check result.
Instance Attribute Details
#additional_info ⇒ Hash<String,String>
Links to sources that provide additional context on the insight.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
The category of the insight.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#category_specific_summary ⇒ Types::InsightCategorySpecificSummary
Summary information that relates to the category of the insight.
Currently only returned with certain insights having category
UPGRADE_READINESS.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the insight which includes alert criteria, remediation recommendation, and additional resources (contains Markdown).
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the insight.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#insight_status ⇒ Types::InsightStatus
An object containing more detail on the status of the insight resource.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#kubernetes_version ⇒ String
The Kubernetes minor version associated with an insight if applicable.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#last_refresh_time ⇒ Time
The time Amazon EKS last successfully completed a refresh of this insight check on the cluster.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#last_transition_time ⇒ Time
The time the status of the insight last changed.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the insight.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#recommendation ⇒ String
A summary of how to remediate the finding of this insight if applicable.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::InsightResourceDetail>
The details about each resource listed in the insight check result.
5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 |
# File 'lib/aws-sdk-eks/types.rb', line 5122 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |