Class: Aws::EKS::Types::KubeSchedulerConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The configuration for the Kubernetes scheduler on an Amazon EKS cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#node_resources_fitTypes::NodeResourcesFitConfig

The node resource fit scoring configuration for the scheduler.



5245
5246
5247
5248
5249
# File 'lib/aws-sdk-eks/types.rb', line 5245

class KubeSchedulerConfigRequest < Struct.new(
  :node_resources_fit)
  SENSITIVE = []
  include Aws::Structure
end