Class: Aws::EKS::Types::ListCapabilitiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_nameString

The name of the Amazon EKS cluster for which you want to list capabilities.

Returns:

  • (String)


6215
6216
6217
6218
6219
6220
6221
# File 'lib/aws-sdk-eks/types.rb', line 6215

class ListCapabilitiesRequest < Struct.new(
  :cluster_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned nextToken value. If you don't specify a value, the default is 100 results.

Returns:

  • (Integer)


6215
6216
6217
6218
6219
6220
6221
# File 'lib/aws-sdk-eks/types.rb', line 6215

class ListCapabilitiesRequest < Struct.new(
  :cluster_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value returned from a previous paginated request, where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

Returns:

  • (String)


6215
6216
6217
6218
6219
6220
6221
# File 'lib/aws-sdk-eks/types.rb', line 6215

class ListCapabilitiesRequest < Struct.new(
  :cluster_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end