Class: Aws::EKS::Types::ListFargateProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ListFargateProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
The name of your cluster.
-
#max_results ⇒ Integer
The maximum number of results, returned in paginated output.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginated request, wheremaxResultswas used and the results exceeded the value of that parameter.
Instance Attribute Details
#cluster_name ⇒ String
The name of your cluster.
6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-eks/types.rb', line 6470 class ListFargateProfilesRequest < Struct.new( :cluster_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results, returned in paginated output. You
receive maxResults in a single page, along with a nextToken
response element. You can see the remaining results of the initial
request by sending another request with the returned nextToken
value. This value can be between 1 and 100. If you don't use this
parameter, 100 results and a nextToken value, if applicable, are
returned.
6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-eks/types.rb', line 6470 class ListFargateProfilesRequest < Struct.new( :cluster_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated request,
where maxResults was used and the results exceeded the value of
that parameter. Pagination continues from the end of the previous
results that returned the nextToken value. This value is null when
there are no more results to return.
6470 6471 6472 6473 6474 6475 6476 |
# File 'lib/aws-sdk-eks/types.rb', line 6470 class ListFargateProfilesRequest < Struct.new( :cluster_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |