Class: Aws::EKS::Types::ListFargateProfilesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fargate_profile_namesArray<String>

A list of all of the Fargate profiles associated with the specified cluster.

Returns:

  • (Array<String>)


6499
6500
6501
6502
6503
6504
# File 'lib/aws-sdk-eks/types.rb', line 6499

class ListFargateProfilesResponse < Struct.new(
  :fargate_profile_names,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value returned from a previous paginated request, where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


6499
6500
6501
6502
6503
6504
# File 'lib/aws-sdk-eks/types.rb', line 6499

class ListFargateProfilesResponse < Struct.new(
  :fargate_profile_names,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end