Class: Aws::EKS::Types::ListIdentityProviderConfigsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identity_provider_configsArray<Types::IdentityProviderConfig>

The identity provider configurations for the cluster.

Returns:



6564
6565
6566
6567
6568
6569
# File 'lib/aws-sdk-eks/types.rb', line 6564

class ListIdentityProviderConfigsResponse < Struct.new(
  :identity_provider_configs,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value to include in a future ListIdentityProviderConfigsResponse request. When the results of a ListIdentityProviderConfigsResponse request exceed maxResults, you can use this value to retrieve the next page of results. This value is null when there are no more results to return.

This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


6564
6565
6566
6567
6568
6569
# File 'lib/aws-sdk-eks/types.rb', line 6564

class ListIdentityProviderConfigsResponse < Struct.new(
  :identity_provider_configs,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end