Class: Aws::EKS::Types::ListInsightsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ListInsightsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#insights ⇒ Array<Types::InsightSummary>
The returned list of insights.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListInsightsrequest.
Instance Attribute Details
#insights ⇒ Array<Types::InsightSummary>
The returned list of insights.
6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-eks/types.rb', line 6624 class ListInsightsResponse < Struct.new( :insights, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future ListInsights request.
When the results of a ListInsights request exceed maxResults,
you can use this value to retrieve the next page of results. This
value is null when there are no more results to return.
6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-eks/types.rb', line 6624 class ListInsightsResponse < Struct.new( :insights, :next_token) SENSITIVE = [] include Aws::Structure end |