Class: Aws::EKS::Types::ListNodegroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_name ⇒ String

The name of your cluster.

Returns:

  • (String)


6675
6676
6677
6678
6679
6680
6681
# File 'lib/aws-sdk-eks/types.rb', line 6675

class ListNodegroupsRequest < Struct.new(
  :cluster_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results, returned in paginated output. You receive maxResults in a single page, along with a nextToken response element. You can see the remaining results of the initial request by sending another request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, 100 results and a nextToken value, if applicable, are returned.

Returns:

  • (Integer)


6675
6676
6677
6678
6679
6680
6681
# File 'lib/aws-sdk-eks/types.rb', line 6675

class ListNodegroupsRequest < Struct.new(
  :cluster_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The nextToken value returned from a previous paginated request, where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


6675
6676
6677
6678
6679
6680
6681
# File 'lib/aws-sdk-eks/types.rb', line 6675

class ListNodegroupsRequest < Struct.new(
  :cluster_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end