Class: Aws::EKS::Types::ListNodegroupsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The nextToken value returned from a previous paginated request, where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


6704
6705
6706
6707
6708
6709
# File 'lib/aws-sdk-eks/types.rb', line 6704

class ListNodegroupsResponse < Struct.new(
  :nodegroups,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#nodegroups ⇒ Array<String>

A list of all of the node groups associated with the specified cluster.

Returns:

  • (Array<String>)


6704
6705
6706
6707
6708
6709
# File 'lib/aws-sdk-eks/types.rb', line 6704

class ListNodegroupsResponse < Struct.new(
  :nodegroups,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end