Class: Aws::EKS::Types::ListPodIdentityAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ListPodIdentityAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
The name of the cluster that the associations are in.
-
#max_results ⇒ Integer
The maximum number of EKS Pod Identity association results returned by
ListPodIdentityAssociationsin paginated output. -
#namespace ⇒ String
The name of the Kubernetes namespace inside the cluster that the associations are in.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedListUpdatesrequest wheremaxResultswas used and the results exceeded the value of that parameter. -
#service_account ⇒ String
The name of the Kubernetes service account that the associations use.
Instance Attribute Details
#cluster_name ⇒ String
The name of the cluster that the associations are in.
6738 6739 6740 6741 6742 6743 6744 6745 6746 |
# File 'lib/aws-sdk-eks/types.rb', line 6738 class ListPodIdentityAssociationsRequest < Struct.new( :cluster_name, :namespace, :service_account, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of EKS Pod Identity association results returned
by ListPodIdentityAssociations in paginated output. When you use
this parameter, ListPodIdentityAssociations returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial
request by sending another ListPodIdentityAssociations request
with the returned nextToken value. This value can be between 1 and
100. If you don't use this parameter, ListPodIdentityAssociations
returns up to 100 results and a nextToken value if applicable.
6738 6739 6740 6741 6742 6743 6744 6745 6746 |
# File 'lib/aws-sdk-eks/types.rb', line 6738 class ListPodIdentityAssociationsRequest < Struct.new( :cluster_name, :namespace, :service_account, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The name of the Kubernetes namespace inside the cluster that the associations are in.
6738 6739 6740 6741 6742 6743 6744 6745 6746 |
# File 'lib/aws-sdk-eks/types.rb', line 6738 class ListPodIdentityAssociationsRequest < Struct.new( :cluster_name, :namespace, :service_account, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated
ListUpdates request where maxResults was used and the results
exceeded the value of that parameter. Pagination continues from the
end of the previous results that returned the nextToken value.
6738 6739 6740 6741 6742 6743 6744 6745 6746 |
# File 'lib/aws-sdk-eks/types.rb', line 6738 class ListPodIdentityAssociationsRequest < Struct.new( :cluster_name, :namespace, :service_account, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_account ⇒ String
The name of the Kubernetes service account that the associations use.
6738 6739 6740 6741 6742 6743 6744 6745 6746 |
# File 'lib/aws-sdk-eks/types.rb', line 6738 class ListPodIdentityAssociationsRequest < Struct.new( :cluster_name, :namespace, :service_account, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |