Class: Aws::EKS::Types::ListPodIdentityAssociationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ListPodIdentityAssociationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associations ⇒ Array<Types::PodIdentityAssociationSummary>
The list of summarized descriptions of the associations that are in the cluster and match any filters that you provided.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListPodIdentityAssociationsrequest.
Instance Attribute Details
#associations ⇒ Array<Types::PodIdentityAssociationSummary>
The list of summarized descriptions of the associations that are in the cluster and match any filters that you provided.
Each summary is simplified by removing these fields compared to the
full PodIdentityAssociation :
-
The IAM role:
roleArn -
The timestamp that the association was created at:
createdAt -
The most recent timestamp that the association was modified at:.
modifiedAt -
The tags on the association:
tags
6785 6786 6787 6788 6789 6790 |
# File 'lib/aws-sdk-eks/types.rb', line 6785 class ListPodIdentityAssociationsResponse < Struct.new( :associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future
ListPodIdentityAssociations request. When the results of a
ListPodIdentityAssociations request exceed maxResults, you can
use this value to retrieve the next page of results. This value is
null when there are no more results to return.
6785 6786 6787 6788 6789 6790 |
# File 'lib/aws-sdk-eks/types.rb', line 6785 class ListPodIdentityAssociationsResponse < Struct.new( :associations, :next_token) SENSITIVE = [] include Aws::Structure end |