Class: Aws::EKS::Types::ListUpdatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ListUpdatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#addon_name ⇒ String
The names of the installed add-ons that have available updates.
-
#capability_name ⇒ String
The name of the capability for which you want to list updates.
-
#max_results ⇒ Integer
The maximum number of results, returned in paginated output.
-
#name ⇒ String
The name of the Amazon EKS cluster to list updates for.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginated request, wheremaxResultswas used and the results exceeded the value of that parameter. -
#nodegroup_name ⇒ String
The name of the Amazon EKS managed node group to list updates for.
Instance Attribute Details
#addon_name ⇒ String
The names of the installed add-ons that have available updates.
6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 |
# File 'lib/aws-sdk-eks/types.rb', line 6859 class ListUpdatesRequest < Struct.new( :name, :nodegroup_name, :addon_name, :capability_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#capability_name ⇒ String
The name of the capability for which you want to list updates.
6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 |
# File 'lib/aws-sdk-eks/types.rb', line 6859 class ListUpdatesRequest < Struct.new( :name, :nodegroup_name, :addon_name, :capability_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results, returned in paginated output. You
receive maxResults in a single page, along with a nextToken
response element. You can see the remaining results of the initial
request by sending another request with the returned nextToken
value. This value can be between 1 and 100. If you don't use this
parameter, 100 results and a nextToken value, if applicable, are
returned.
6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 |
# File 'lib/aws-sdk-eks/types.rb', line 6859 class ListUpdatesRequest < Struct.new( :name, :nodegroup_name, :addon_name, :capability_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon EKS cluster to list updates for.
6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 |
# File 'lib/aws-sdk-eks/types.rb', line 6859 class ListUpdatesRequest < Struct.new( :name, :nodegroup_name, :addon_name, :capability_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated request,
where maxResults was used and the results exceeded the value of
that parameter. Pagination continues from the end of the previous
results that returned the nextToken value. This value is null when
there are no more results to return.
6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 |
# File 'lib/aws-sdk-eks/types.rb', line 6859 class ListUpdatesRequest < Struct.new( :name, :nodegroup_name, :addon_name, :capability_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#nodegroup_name ⇒ String
The name of the Amazon EKS managed node group to list updates for.
6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 |
# File 'lib/aws-sdk-eks/types.rb', line 6859 class ListUpdatesRequest < Struct.new( :name, :nodegroup_name, :addon_name, :capability_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |