Class: Aws::EKS::Types::ListUpdatesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The nextToken value returned from a previous paginated request, where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


6890
6891
6892
6893
6894
6895
# File 'lib/aws-sdk-eks/types.rb', line 6890

class ListUpdatesResponse < Struct.new(
  :update_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#update_idsArray<String>

A list of all the updates for the specified cluster and Region.

Returns:

  • (Array<String>)


6890
6891
6892
6893
6894
6895
# File 'lib/aws-sdk-eks/types.rb', line 6890

class ListUpdatesResponse < Struct.new(
  :update_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end