Class: Aws::EKS::Types::NodeResourcesFitConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::NodeResourcesFitConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The NodeResourcesFit plugin configuration for the Kubernetes scheduler.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#scoring_strategy ⇒ Types::ScoringStrategy
The scoring strategy used to rank nodes during scheduling.
Instance Attribute Details
#scoring_strategy ⇒ Types::ScoringStrategy
The scoring strategy used to rank nodes during scheduling.
6998 6999 7000 7001 7002 |
# File 'lib/aws-sdk-eks/types.rb', line 6998 class NodeResourcesFitConfig < Struct.new( :scoring_strategy) SENSITIVE = [] include Aws::Structure end |