Class: Aws::EKS::Types::NotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::NotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
A service resource associated with the request could not be found. Clients should not retry such requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A service resource associated with the request could not be found.
Instance Attribute Details
#message ⇒ String
A service resource associated with the request could not be found. Clients should not retry such requests.
6905 6906 6907 6908 6909 |
# File 'lib/aws-sdk-eks/types.rb', line 6905 class NotFoundException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |