Class: Aws::EKS::Types::OutpostConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::OutpostConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The configuration of your local Amazon EKS cluster on an Amazon Web Services Outpost. Before creating a cluster on an Outpost, review Creating a local cluster on an Outpost in the Amazon EKS User Guide. This API isn't available for Amazon EKS clusters on the Amazon Web Services cloud.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#control_plane_instance_type ⇒ String
The Amazon EC2 instance type for the Kubernetes control plane instances of your local Amazon EKS cluster on Amazon Web Services Outposts.
-
#control_plane_placement ⇒ Types::ControlPlanePlacementRequest
An object representing the placement configuration for all the control plane instances of your local Amazon EKS cluster on an Amazon Web Services Outpost.
-
#etcd_instance_type ⇒ String
The Amazon EC2 instance type for etcd instances of your local Amazon EKS cluster on Amazon Web Services Outposts.
-
#etcd_placement ⇒ Types::EtcdPlacementRequest
An object representing the placement configuration for the etcd instances of your local Amazon EKS cluster on an Amazon Web Services Outpost.
-
#outpost_arns ⇒ Array<String>
The ARN of the Outpost that you want to use for your local Amazon EKS cluster on Outposts.
Instance Attribute Details
#control_plane_instance_type ⇒ String
The Amazon EC2 instance type for the Kubernetes control plane instances of your local Amazon EKS cluster on Amazon Web Services Outposts. This instance type applies to all control plane instances and cannot be changed after cluster creation.
For more information, see Capacity considerations in the Amazon EKS User Guide.
7158 7159 7160 7161 7162 7163 7164 7165 7166 |
# File 'lib/aws-sdk-eks/types.rb', line 7158 class OutpostConfigRequest < Struct.new( :outpost_arns, :control_plane_instance_type, :control_plane_placement, :etcd_instance_type, :etcd_placement) SENSITIVE = [] include Aws::Structure end |
#control_plane_placement ⇒ Types::ControlPlanePlacementRequest
An object representing the placement configuration for all the control plane instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see Capacity considerations in the Amazon EKS User Guide.
7158 7159 7160 7161 7162 7163 7164 7165 7166 |
# File 'lib/aws-sdk-eks/types.rb', line 7158 class OutpostConfigRequest < Struct.new( :outpost_arns, :control_plane_instance_type, :control_plane_placement, :etcd_instance_type, :etcd_placement) SENSITIVE = [] include Aws::Structure end |
#etcd_instance_type ⇒ String
The Amazon EC2 instance type for etcd instances of your local Amazon EKS cluster on Amazon Web Services Outposts. This instance type applies to all etcd instances and cannot be changed after cluster creation.
7158 7159 7160 7161 7162 7163 7164 7165 7166 |
# File 'lib/aws-sdk-eks/types.rb', line 7158 class OutpostConfigRequest < Struct.new( :outpost_arns, :control_plane_instance_type, :control_plane_placement, :etcd_instance_type, :etcd_placement) SENSITIVE = [] include Aws::Structure end |
#etcd_placement ⇒ Types::EtcdPlacementRequest
An object representing the placement configuration for the etcd instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see Capacity considerations in the Amazon EKS User Guide.
7158 7159 7160 7161 7162 7163 7164 7165 7166 |
# File 'lib/aws-sdk-eks/types.rb', line 7158 class OutpostConfigRequest < Struct.new( :outpost_arns, :control_plane_instance_type, :control_plane_placement, :etcd_instance_type, :etcd_placement) SENSITIVE = [] include Aws::Structure end |
#outpost_arns ⇒ Array<String>
The ARN of the Outpost that you want to use for your local Amazon EKS cluster on Outposts. Only a single Outpost ARN is supported.
7158 7159 7160 7161 7162 7163 7164 7165 7166 |
# File 'lib/aws-sdk-eks/types.rb', line 7158 class OutpostConfigRequest < Struct.new( :outpost_arns, :control_plane_instance_type, :control_plane_placement, :etcd_instance_type, :etcd_placement) SENSITIVE = [] include Aws::Structure end |