Class: Aws::EKS::Types::PodGcControllerConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The pod garbage collection controller configuration for the Kubernetes controller manager.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#terminated_pod_gc_thresholdInteger

The number of terminated pods that can exist before the garbage collector starts deleting them.

Returns:

  • (Integer)


7737
7738
7739
7740
7741
# File 'lib/aws-sdk-eks/types.rb', line 7737

class PodGcControllerConfigRequest < Struct.new(
  :terminated_pod_gc_threshold)
  SENSITIVE = []
  include Aws::Structure
end