Class: Aws::EKS::Types::PodGcControllerConfigResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The pod garbage collection controller configuration for the Kubernetes controller manager.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#terminated_pod_gc_thresholdInteger

The number of terminated pods that can exist before the garbage collector starts deleting them.

Returns:

  • (Integer)


7753
7754
7755
7756
7757
# File 'lib/aws-sdk-eks/types.rb', line 7753

class PodGcControllerConfigResponse < Struct.new(
  :terminated_pod_gc_threshold)
  SENSITIVE = []
  include Aws::Structure
end