Class: Aws::EKS::Types::PodIdentityAssociationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::PodIdentityAssociationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The summarized description of the association.
Each summary is simplified by removing these fields compared to the
full PodIdentityAssociation :
-
The IAM role:
roleArn -
The timestamp that the association was created at:
createdAt -
The most recent timestamp that the association was modified at:.
modifiedAt -
The tags on the association:
tags
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#association_id ⇒ String
The ID of the association.
-
#cluster_name ⇒ String
The name of the cluster that the association is in.
-
#namespace ⇒ String
The name of the Kubernetes namespace inside the cluster to create the association in.
-
#owner_arn ⇒ String
If defined, the association is owned by an Amazon EKS add-on.
-
#service_account ⇒ String
The name of the Kubernetes service account inside the cluster to associate the IAM credentials with.
Instance Attribute Details
#association_arn ⇒ String
The Amazon Resource Name (ARN) of the association.
7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 |
# File 'lib/aws-sdk-eks/types.rb', line 7974 class PodIdentityAssociationSummary < Struct.new( :cluster_name, :namespace, :service_account, :association_arn, :association_id, :owner_arn) SENSITIVE = [] include Aws::Structure end |
#association_id ⇒ String
The ID of the association.
7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 |
# File 'lib/aws-sdk-eks/types.rb', line 7974 class PodIdentityAssociationSummary < Struct.new( :cluster_name, :namespace, :service_account, :association_arn, :association_id, :owner_arn) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of the cluster that the association is in.
7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 |
# File 'lib/aws-sdk-eks/types.rb', line 7974 class PodIdentityAssociationSummary < Struct.new( :cluster_name, :namespace, :service_account, :association_arn, :association_id, :owner_arn) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The name of the Kubernetes namespace inside the cluster to create the association in. The service account and the Pods that use the service account must be in this namespace.
7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 |
# File 'lib/aws-sdk-eks/types.rb', line 7974 class PodIdentityAssociationSummary < Struct.new( :cluster_name, :namespace, :service_account, :association_arn, :association_id, :owner_arn) SENSITIVE = [] include Aws::Structure end |
#owner_arn ⇒ String
If defined, the association is owned by an Amazon EKS add-on.
7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 |
# File 'lib/aws-sdk-eks/types.rb', line 7974 class PodIdentityAssociationSummary < Struct.new( :cluster_name, :namespace, :service_account, :association_arn, :association_id, :owner_arn) SENSITIVE = [] include Aws::Structure end |
#service_account ⇒ String
The name of the Kubernetes service account inside the cluster to associate the IAM credentials with.
7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 |
# File 'lib/aws-sdk-eks/types.rb', line 7974 class PodIdentityAssociationSummary < Struct.new( :cluster_name, :namespace, :service_account, :association_arn, :association_id, :owner_arn) SENSITIVE = [] include Aws::Structure end |