Class: Aws::EKS::Types::Provider

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Identifies the Key Management Service (KMS) key used to encrypt the secrets.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_arnString

Amazon Resource Name (ARN) or alias of the KMS key. The KMS key must be symmetric and created in the same Amazon Web Services Region as the cluster. If the KMS key was created in a different account, the

IAM principal][1

must have access to the KMS key. For more

information, see [Allowing users in other accounts to use a KMS key] in the *Key Management Service Developer Guide*.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html [2]: docs.aws.amazon.com/kms/latest/developerguide/key-policy-modifying-external-accounts.html

Returns:

  • (String)


6991
6992
6993
6994
6995
# File 'lib/aws-sdk-eks/types.rb', line 6991

class Provider < Struct.new(
  :key_arn)
  SENSITIVE = []
  include Aws::Structure
end