Class: Aws::EKS::Types::RollbackConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::RollbackConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The rollback configuration for the cluster version rollback.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#timeout_minutes ⇒ Integer
The length of time in minutes to wait before cancelling the update.
Instance Attribute Details
#timeout_minutes ⇒ Integer
The length of time in minutes to wait before cancelling the update.
Timeout is a minimum-bound property, meaning the timeout occurs no
sooner than the time you specify, but can occur shortly thereafter.
This value can be between 120 (2 hours) and 10080 (7 days). Default:
720 (12 hours) if not specified.
8523 8524 8525 8526 8527 |
# File 'lib/aws-sdk-eks/types.rb', line 8523 class RollbackConfig < Struct.new( :timeout_minutes) SENSITIVE = [] include Aws::Structure end |