Class: Aws::EKS::Types::Taint
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::Taint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
A property that allows a node to repel a Pod. For more information,
see Node taints on managed node groups in the Amazon EKS User
Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#effect ⇒ String
The effect of the taint.
-
#key ⇒ String
The key of the taint.
-
#value ⇒ String
The value of the taint.
Instance Attribute Details
#effect ⇒ String
The effect of the taint.
8236 8237 8238 8239 8240 8241 8242 |
# File 'lib/aws-sdk-eks/types.rb', line 8236 class Taint < Struct.new( :key, :value, :effect) SENSITIVE = [] include Aws::Structure end |