Class: Aws::EKS::Types::UnsupportedAvailabilityZoneException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

At least one of your specified cluster subnets is in an Availability Zone that does not support Amazon EKS. The exception output specifies the supported Availability Zones for your account, from which you can choose subnets for your cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_nameString

The Amazon EKS cluster associated with the exception.

Returns:

  • (String)


8844
8845
8846
8847
8848
8849
8850
8851
# File 'lib/aws-sdk-eks/types.rb', line 8844

class UnsupportedAvailabilityZoneException < Struct.new(
  :message,
  :cluster_name,
  :nodegroup_name,
  :valid_zones)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

At least one of your specified cluster subnets is in an Availability Zone that does not support Amazon EKS. The exception output specifies the supported Availability Zones for your account, from which you can choose subnets for your cluster.

Returns:

  • (String)


8844
8845
8846
8847
8848
8849
8850
8851
# File 'lib/aws-sdk-eks/types.rb', line 8844

class UnsupportedAvailabilityZoneException < Struct.new(
  :message,
  :cluster_name,
  :nodegroup_name,
  :valid_zones)
  SENSITIVE = []
  include Aws::Structure
end

#nodegroup_nameString

The Amazon EKS managed node group associated with the exception.

Returns:

  • (String)


8844
8845
8846
8847
8848
8849
8850
8851
# File 'lib/aws-sdk-eks/types.rb', line 8844

class UnsupportedAvailabilityZoneException < Struct.new(
  :message,
  :cluster_name,
  :nodegroup_name,
  :valid_zones)
  SENSITIVE = []
  include Aws::Structure
end

#valid_zonesArray<String>

The supported Availability Zones for your account. Choose subnets in these Availability Zones for your cluster.

Returns:

  • (Array<String>)


8844
8845
8846
8847
8848
8849
8850
8851
# File 'lib/aws-sdk-eks/types.rb', line 8844

class UnsupportedAvailabilityZoneException < Struct.new(
  :message,
  :cluster_name,
  :nodegroup_name,
  :valid_zones)
  SENSITIVE = []
  include Aws::Structure
end