Class: Aws::EKS::Types::UpdateCapabilityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capability_name ⇒ String

The name of the capability to update configuration for.

Returns:

  • (String)


9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
# File 'lib/aws-sdk-eks/types.rb', line 9220

class UpdateCapabilityRequest < Struct.new(
  :cluster_name,
  :capability_name,
  :role_arn,
  :configuration,
  :client_request_token,
  :delete_propagation_policy)
  SENSITIVE = []
  include Aws::Structure
end

#client_request_token ⇒ String

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This token is valid for 24 hours after creation.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
# File 'lib/aws-sdk-eks/types.rb', line 9220

class UpdateCapabilityRequest < Struct.new(
  :cluster_name,
  :capability_name,
  :role_arn,
  :configuration,
  :client_request_token,
  :delete_propagation_policy)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_name ⇒ String

The name of the Amazon EKS cluster that contains the capability you want to update configuration for.

Returns:

  • (String)


9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
# File 'lib/aws-sdk-eks/types.rb', line 9220

class UpdateCapabilityRequest < Struct.new(
  :cluster_name,
  :capability_name,
  :role_arn,
  :configuration,
  :client_request_token,
  :delete_propagation_policy)
  SENSITIVE = []
  include Aws::Structure
end

#configuration ⇒ Types::UpdateCapabilityConfiguration

The updated configuration settings for the capability. You only need to specify the configuration parameters you want to change. For Argo CD capabilities, you can update RBAC role mappings and network access settings.



9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
# File 'lib/aws-sdk-eks/types.rb', line 9220

class UpdateCapabilityRequest < Struct.new(
  :cluster_name,
  :capability_name,
  :role_arn,
  :configuration,
  :client_request_token,
  :delete_propagation_policy)
  SENSITIVE = []
  include Aws::Structure
end

#delete_propagation_policy ⇒ String

The updated delete propagation policy for the capability. Currently, the only supported value is RETAIN.

Returns:

  • (String)


9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
# File 'lib/aws-sdk-eks/types.rb', line 9220

class UpdateCapabilityRequest < Struct.new(
  :cluster_name,
  :capability_name,
  :role_arn,
  :configuration,
  :client_request_token,
  :delete_propagation_policy)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The Amazon Resource Name (ARN) of the IAM role that the capability uses to interact with Amazon Web Services services. If you specify a new role ARN, the capability will start using the new role for all subsequent operations.

Returns:

  • (String)


9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
# File 'lib/aws-sdk-eks/types.rb', line 9220

class UpdateCapabilityRequest < Struct.new(
  :cluster_name,
  :capability_name,
  :role_arn,
  :configuration,
  :client_request_token,
  :delete_propagation_policy)
  SENSITIVE = []
  include Aws::Structure
end