Class: Aws::EKS::Types::UpdateClusterConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_configTypes::UpdateAccessConfigRequest

The access configuration for the cluster.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#client_request_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#compute_configTypes::ComputeConfigRequest

Update the configuration of the compute capability of your EKS Auto Mode cluster. For example, enable the capability.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#control_plane_scaling_configTypes::ControlPlaneScalingConfig

The control plane scaling tier configuration. For more information, see EKS Provisioned Control Plane in the Amazon EKS User Guide.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protectionBoolean

Specifies whether to enable or disable deletion protection for the cluster. When enabled (true), the cluster cannot be deleted until deletion protection is explicitly disabled. When disabled (false), the cluster can be deleted normally.

Returns:

  • (Boolean)


9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#kube_api_server_configTypes::KubeApiServerConfigRequest

The Kubernetes API server configuration for the updated cluster.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#kube_controller_manager_configTypes::KubeControllerManagerConfigRequest

The Kubernetes controller manager configuration for the updated cluster.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#kube_scheduler_configTypes::KubeSchedulerConfigRequest

The Kubernetes scheduler configuration for the updated cluster.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#kubernetes_network_configTypes::KubernetesNetworkConfigRequest

The Kubernetes network configuration for the cluster.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#loggingTypes::Logging

Enable or disable exporting the Kubernetes control plane logs for your cluster to CloudWatch Logs . By default, cluster control plane logs aren't exported to CloudWatch Logs . For more information, see Amazon EKS cluster control plane logs in the Amazon EKS User Guide .

CloudWatch Logs ingestion, archive storage, and data scanning rates apply to exported control plane logs. For more information, see CloudWatch Pricing.

Returns:



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon EKS cluster to update.

Returns:

  • (String)


9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#remote_network_configTypes::RemoteNetworkConfigRequest

The configuration in the cluster for EKS Hybrid Nodes. You can add, change, or remove this configuration after the cluster is created.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#resources_vpc_configTypes::VpcConfigRequest

An object representing the VPC configuration to use for the cluster update. You can use this parameter to update the control plane egress mode, the subnets used by the cluster, the security groups, and the endpoint access settings.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#storage_configTypes::StorageConfigRequest

Update the configuration of the block storage capability of your EKS Auto Mode cluster. For example, enable the capability.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#upgrade_policyTypes::UpgradePolicyRequest

You can enable or disable extended support for clusters currently on standard support. You cannot disable extended support once it starts. You must enable extended support before your cluster exits standard support.



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end

#zonal_shift_configTypes::ZonalShiftConfigRequest

Enable or disable ARC zonal shift for the cluster. If zonal shift is enabled, Amazon Web Services configures zonal autoshift for the cluster.

Zonal shift is a feature of Amazon Application Recovery Controller (ARC). ARC zonal shift is designed to be a temporary measure that allows you to move traffic for a resource away from an impaired AZ until the zonal shift expires or you cancel it. You can extend the zonal shift if necessary.

You can start a zonal shift for an EKS cluster, or you can allow Amazon Web Services to do it for you by enabling zonal autoshift. This shift updates the flow of east-to-west network traffic in your cluster to only consider network endpoints for Pods running on worker nodes in healthy AZs. Additionally, any ALB or NLB handling ingress traffic for applications in your EKS cluster will automatically route traffic to targets in the healthy AZs. For more information about zonal shift in EKS, see Learn about Amazon Application Recovery Controller (ARC) Zonal Shift in Amazon EKS in the Amazon EKS User Guide .



9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-eks/types.rb', line 9246

class UpdateClusterConfigRequest < Struct.new(
  :name,
  :resources_vpc_config,
  :logging,
  :client_request_token,
  :access_config,
  :upgrade_policy,
  :zonal_shift_config,
  :compute_config,
  :kubernetes_network_config,
  :storage_config,
  :remote_network_config,
  :deletion_protection,
  :control_plane_scaling_config,
  :kube_api_server_config,
  :kube_scheduler_config,
  :kube_controller_manager_config)
  SENSITIVE = []
  include Aws::Structure
end