Class: Aws::EKS::Types::UpdateNodegroupConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::UpdateNodegroupConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_name ⇒ String
The name of your cluster.
-
#labels ⇒ Types::UpdateLabelsPayload
The Kubernetes
labelsto apply to the nodes in the node group after the update. -
#node_repair_config ⇒ Types::NodeRepairConfig
The node auto repair configuration for the node group.
-
#nodegroup_name ⇒ String
The name of the managed node group to update.
-
#scaling_config ⇒ Types::NodegroupScalingConfig
The scaling configuration details for the Auto Scaling group after the update.
-
#taints ⇒ Types::UpdateTaintsPayload
The Kubernetes taints to be applied to the nodes in the node group after the update.
-
#update_config ⇒ Types::NodegroupUpdateConfig
The node group update configuration.
-
#warm_pool_config ⇒ Types::WarmPoolConfig
The warm pool configuration to apply to the node group.
Instance Attribute Details
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 |
# File 'lib/aws-sdk-eks/types.rb', line 9439 class UpdateNodegroupConfigRequest < Struct.new( :cluster_name, :nodegroup_name, :labels, :taints, :scaling_config, :update_config, :node_repair_config, :warm_pool_config, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of your cluster.
9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 |
# File 'lib/aws-sdk-eks/types.rb', line 9439 class UpdateNodegroupConfigRequest < Struct.new( :cluster_name, :nodegroup_name, :labels, :taints, :scaling_config, :update_config, :node_repair_config, :warm_pool_config, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#labels ⇒ Types::UpdateLabelsPayload
The Kubernetes labels to apply to the nodes in the node group
after the update.
9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 |
# File 'lib/aws-sdk-eks/types.rb', line 9439 class UpdateNodegroupConfigRequest < Struct.new( :cluster_name, :nodegroup_name, :labels, :taints, :scaling_config, :update_config, :node_repair_config, :warm_pool_config, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#node_repair_config ⇒ Types::NodeRepairConfig
The node auto repair configuration for the node group.
9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 |
# File 'lib/aws-sdk-eks/types.rb', line 9439 class UpdateNodegroupConfigRequest < Struct.new( :cluster_name, :nodegroup_name, :labels, :taints, :scaling_config, :update_config, :node_repair_config, :warm_pool_config, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#nodegroup_name ⇒ String
The name of the managed node group to update.
9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 |
# File 'lib/aws-sdk-eks/types.rb', line 9439 class UpdateNodegroupConfigRequest < Struct.new( :cluster_name, :nodegroup_name, :labels, :taints, :scaling_config, :update_config, :node_repair_config, :warm_pool_config, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#scaling_config ⇒ Types::NodegroupScalingConfig
The scaling configuration details for the Auto Scaling group after the update.
9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 |
# File 'lib/aws-sdk-eks/types.rb', line 9439 class UpdateNodegroupConfigRequest < Struct.new( :cluster_name, :nodegroup_name, :labels, :taints, :scaling_config, :update_config, :node_repair_config, :warm_pool_config, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#taints ⇒ Types::UpdateTaintsPayload
The Kubernetes taints to be applied to the nodes in the node group after the update. For more information, see Node taints on managed node groups.
9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 |
# File 'lib/aws-sdk-eks/types.rb', line 9439 class UpdateNodegroupConfigRequest < Struct.new( :cluster_name, :nodegroup_name, :labels, :taints, :scaling_config, :update_config, :node_repair_config, :warm_pool_config, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#update_config ⇒ Types::NodegroupUpdateConfig
The node group update configuration.
9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 |
# File 'lib/aws-sdk-eks/types.rb', line 9439 class UpdateNodegroupConfigRequest < Struct.new( :cluster_name, :nodegroup_name, :labels, :taints, :scaling_config, :update_config, :node_repair_config, :warm_pool_config, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#warm_pool_config ⇒ Types::WarmPoolConfig
The warm pool configuration to apply to the node group. You can use this to add a warm pool to an existing node group or modify the settings of an existing warm pool.
9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 |
# File 'lib/aws-sdk-eks/types.rb', line 9439 class UpdateNodegroupConfigRequest < Struct.new( :cluster_name, :nodegroup_name, :labels, :taints, :scaling_config, :update_config, :node_repair_config, :warm_pool_config, :client_request_token) SENSITIVE = [] include Aws::Structure end |