Class: Aws::EKS::Types::UpdateNodegroupVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::UpdateNodegroupVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_name ⇒ String
The name of your cluster.
-
#force ⇒ Boolean
Force the update if any
Podon the existing node group can’t be drained due to aPoddisruption budget issue. -
#launch_template ⇒ Types::LaunchTemplateSpecification
An object representing a node group’s launch template specification.
-
#nodegroup_name ⇒ String
The name of the managed node group to update.
-
#release_version ⇒ String
The AMI version of the Amazon EKS optimized AMI to use for the update.
-
#version ⇒ String
The Kubernetes version to update to.
Instance Attribute Details
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 |
# File 'lib/aws-sdk-eks/types.rb', line 6829 class UpdateNodegroupVersionRequest < Struct.new( :cluster_name, :nodegroup_name, :version, :release_version, :launch_template, :force, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of your cluster.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 |
# File 'lib/aws-sdk-eks/types.rb', line 6829 class UpdateNodegroupVersionRequest < Struct.new( :cluster_name, :nodegroup_name, :version, :release_version, :launch_template, :force, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Force the update if any Pod on the existing node group can’t be drained due to a Pod disruption budget issue. If an update fails because all Pods can’t be drained, you can force the update after it fails to terminate the old node whether or not any Pod is running on the node.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 |
# File 'lib/aws-sdk-eks/types.rb', line 6829 class UpdateNodegroupVersionRequest < Struct.new( :cluster_name, :nodegroup_name, :version, :release_version, :launch_template, :force, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#launch_template ⇒ Types::LaunchTemplateSpecification
An object representing a node group’s launch template specification. You can only update a node group using a launch template if the node group was originally deployed with a launch template.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 |
# File 'lib/aws-sdk-eks/types.rb', line 6829 class UpdateNodegroupVersionRequest < Struct.new( :cluster_name, :nodegroup_name, :version, :release_version, :launch_template, :force, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#nodegroup_name ⇒ String
The name of the managed node group to update.
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 |
# File 'lib/aws-sdk-eks/types.rb', line 6829 class UpdateNodegroupVersionRequest < Struct.new( :cluster_name, :nodegroup_name, :version, :release_version, :launch_template, :force, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#release_version ⇒ String
The AMI version of the Amazon EKS optimized AMI to use for the update. By default, the latest available AMI version for the node group’s Kubernetes version is used. For information about Linux versions, see [Amazon EKS optimized Amazon Linux AMI versions] in the *Amazon EKS User Guide*. Amazon EKS managed node groups support the November 2022 and later releases of the Windows AMIs. For information about Windows versions, see [Amazon EKS optimized Windows AMI versions] in the *Amazon EKS User Guide*.
If you specify launchTemplate, and your launch template uses a custom AMI, then don’t specify releaseVersion, or the node group update will fail. For more information about using launch templates with Amazon EKS, see [Customizing managed nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/eks-linux-ami-versions.html [2]: docs.aws.amazon.com/eks/latest/userguide/eks-ami-versions-windows.html [3]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 |
# File 'lib/aws-sdk-eks/types.rb', line 6829 class UpdateNodegroupVersionRequest < Struct.new( :cluster_name, :nodegroup_name, :version, :release_version, :launch_template, :force, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The Kubernetes version to update to. If no version is specified, then the Kubernetes version of the node group does not change. You can specify the Kubernetes version of the cluster to update the node group to the latest AMI version of the cluster’s Kubernetes version. If you specify launchTemplate, and your launch template uses a custom AMI, then don’t specify version, or the node group update will fail. For more information about using launch templates with Amazon EKS, see [Customizing managed nodes with launch templates] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/launch-templates.html
6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 |
# File 'lib/aws-sdk-eks/types.rb', line 6829 class UpdateNodegroupVersionRequest < Struct.new( :cluster_name, :nodegroup_name, :version, :release_version, :launch_template, :force, :client_request_token) SENSITIVE = [] include Aws::Structure end |