Class: Aws::EKS::Types::UpdateRoleMappings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Updates to RBAC role mappings for an Argo CD capability. You can add, update, or remove role mappings in a single operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_or_update_role_mappingsArray<Types::ArgoCdRoleMapping>

A list of role mappings to add or update. If a mapping for the specified role already exists, it will be updated with the new identities. If it doesn't exist, a new mapping will be created.



9818
9819
9820
9821
9822
9823
# File 'lib/aws-sdk-eks/types.rb', line 9818

class UpdateRoleMappings < Struct.new(
  :add_or_update_role_mappings,
  :remove_role_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#remove_role_mappingsArray<Types::ArgoCdRoleMapping>

A list of role mappings to remove from the RBAC configuration. Each mapping specifies an Argo CD role (ADMIN, EDITOR, or VIEWER) and the identities to remove from that role.



9818
9819
9820
9821
9822
9823
# File 'lib/aws-sdk-eks/types.rb', line 9818

class UpdateRoleMappings < Struct.new(
  :add_or_update_role_mappings,
  :remove_role_mappings)
  SENSITIVE = []
  include Aws::Structure
end