Class: Aws::EKS::Types::UpgradePolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::UpgradePolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
This value indicates if extended support is enabled or disabled for the cluster.
Learn more about EKS Extended Support in the Amazon EKS User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#support_type ⇒ String
If the cluster is set to
EXTENDED, it will enter extended support at the end of standard support.
Instance Attribute Details
#support_type ⇒ String
If the cluster is set to EXTENDED, it will enter extended support
at the end of standard support. If the cluster is set to STANDARD,
it will be automatically upgraded at the end of standard support.
Learn more about EKS Extended Support in the Amazon EKS User Guide.
9803 9804 9805 9806 9807 |
# File 'lib/aws-sdk-eks/types.rb', line 9803 class UpgradePolicyResponse < Struct.new( :support_type) SENSITIVE = [] include Aws::Structure end |