Class: Aws::EKS::Waiters::AddonActive
- Inherits:
-
Object
- Object
- Aws::EKS::Waiters::AddonActive
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-eks/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AddonActive
constructor
A new instance of AddonActive.
-
#wait(params = {}) ⇒ Types::DescribeAddonResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AddonActive
Returns a new instance of AddonActive.
91 92 |
# File 'lib/aws-sdk-eks/waiters.rb', line 91
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
129 130 131 |
# File 'lib/aws-sdk-eks/waiters.rb', line 129 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeAddonResponse
Returns a response object which responds to the following methods:
- #addon => Types::Addon
124 |
# File 'lib/aws-sdk-eks/waiters.rb', line 124
def wait: (
|