Class: Aws::EKS::Waiters::CertificateAuthorityUpdateComplete
- Inherits:
-
Object
- Object
- Aws::EKS::Waiters::CertificateAuthorityUpdateComplete
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-eks/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CertificateAuthorityUpdateComplete
constructor
A new instance of CertificateAuthorityUpdateComplete.
-
#wait(params = {}) ⇒ Types::DescribeUpdateResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CertificateAuthorityUpdateComplete
Returns a new instance of CertificateAuthorityUpdateComplete.
185 186 |
# File 'lib/aws-sdk-eks/waiters.rb', line 185
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
223 224 225 |
# File 'lib/aws-sdk-eks/waiters.rb', line 223 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeUpdateResponse
Returns a response object which responds to the following methods:
- #update => Types::Update
218 |
# File 'lib/aws-sdk-eks/waiters.rb', line 218
def wait: (
|