Class: Aws::EKS::Waiters::FargateProfileActive
- Inherits:
-
Object
- Object
- Aws::EKS::Waiters::FargateProfileActive
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-eks/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FargateProfileActive
constructor
A new instance of FargateProfileActive.
-
#wait(params = {}) ⇒ Types::DescribeFargateProfileResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FargateProfileActive
Returns a new instance of FargateProfileActive.
289 290 |
# File 'lib/aws-sdk-eks/waiters.rb', line 289
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
321 322 323 |
# File 'lib/aws-sdk-eks/waiters.rb', line 321 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeFargateProfileResponse
Returns a response object which responds to the following methods:
- #fargate_profile => Types::FargateProfile
316 |
# File 'lib/aws-sdk-eks/waiters.rb', line 316
def wait: (
|