Class: Aws::EKS::Waiters::FargateProfileDeleted
- Inherits:
-
Object
- Object
- Aws::EKS::Waiters::FargateProfileDeleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-eks/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FargateProfileDeleted
constructor
A new instance of FargateProfileDeleted.
-
#wait(params = {}) ⇒ Types::DescribeFargateProfileResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FargateProfileDeleted
Returns a new instance of FargateProfileDeleted.
333 334 |
# File 'lib/aws-sdk-eks/waiters.rb', line 333
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
364 365 366 |
# File 'lib/aws-sdk-eks/waiters.rb', line 364 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeFargateProfileResponse
Returns a response object which responds to the following methods:
- #fargate_profile => Types::FargateProfile
359 |
# File 'lib/aws-sdk-eks/waiters.rb', line 359
def wait: (
|