Class: Aws::EKS::Types::ActivateCertificateAuthorityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ActivateCertificateAuthorityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_authority_id ⇒ String
The ID of the certificate authority to activate as the cluster's signing certificate authority.
-
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_name ⇒ String
The name of your cluster.
Instance Attribute Details
#certificate_authority_id ⇒ String
The ID of the certificate authority to activate as the cluster's
signing certificate authority. This certificate authority must
already exist on the cluster and have a distributionStatus of
COMPLETE.
207 208 209 210 211 212 213 |
# File 'lib/aws-sdk-eks/types.rb', line 207 class ActivateCertificateAuthorityRequest < Struct.new( :cluster_name, :certificate_authority_id, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
207 208 209 210 211 212 213 |
# File 'lib/aws-sdk-eks/types.rb', line 207 class ActivateCertificateAuthorityRequest < Struct.new( :cluster_name, :certificate_authority_id, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of your cluster.
207 208 209 210 211 212 213 |
# File 'lib/aws-sdk-eks/types.rb', line 207 class ActivateCertificateAuthorityRequest < Struct.new( :cluster_name, :certificate_authority_id, :client_request_token) SENSITIVE = [] include Aws::Structure end |