Class: Aws::EKS::Types::ActivateCertificateAuthorityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ActivateCertificateAuthorityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_authority ⇒ Types::CertificateAuthoritySummary
Summary information about the certificate authority that is being activated.
-
#update ⇒ Types::Update
An object representing the asynchronous update that promotes the certificate authority to be the cluster's signer.
Instance Attribute Details
#certificate_authority ⇒ Types::CertificateAuthoritySummary
Summary information about the certificate authority that is being activated.
227 228 229 230 231 232 |
# File 'lib/aws-sdk-eks/types.rb', line 227 class ActivateCertificateAuthorityResponse < Struct.new( :update, :certificate_authority) SENSITIVE = [] include Aws::Structure end |
#update ⇒ Types::Update
An object representing the asynchronous update that promotes the certificate authority to be the cluster's signer.
227 228 229 230 231 232 |
# File 'lib/aws-sdk-eks/types.rb', line 227 class ActivateCertificateAuthorityResponse < Struct.new( :update, :certificate_authority) SENSITIVE = [] include Aws::Structure end |