Class: Aws::EKS::Types::ActiveCertificateAuthority
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ActiveCertificateAuthority
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Identifies the certificate authority that is currently signing certificates for the cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activated_by ⇒ String
The entity that activated the current signing certificate authority, either
CUSTOMERorEKS. -
#id ⇒ String
The unique identifier of the certificate authority that is currently signing certificates for the cluster.
Instance Attribute Details
#activated_by ⇒ String
The entity that activated the current signing certificate authority,
either CUSTOMER or EKS.
249 250 251 252 253 254 |
# File 'lib/aws-sdk-eks/types.rb', line 249 class ActiveCertificateAuthority < Struct.new( :id, :activated_by) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the certificate authority that is currently signing certificates for the cluster.
249 250 251 252 253 254 |
# File 'lib/aws-sdk-eks/types.rb', line 249 class ActiveCertificateAuthority < Struct.new( :id, :activated_by) SENSITIVE = [] include Aws::Structure end |