Class: Aws::EKS::Types::Certificate
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::Certificate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
An object representing the certificate-authority-data for your
cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active ⇒ Types::ActiveCertificateAuthority
An object identifying the certificate authority that is currently signing certificates for the cluster.
-
#data ⇒ String
The Base64-encoded certificate data required to communicate with your cluster.
Instance Attribute Details
#active ⇒ Types::ActiveCertificateAuthority
An object identifying the certificate authority that is currently signing certificates for the cluster.
1355 1356 1357 1358 1359 1360 |
# File 'lib/aws-sdk-eks/types.rb', line 1355 class Certificate < Struct.new( :data, :active) SENSITIVE = [] include Aws::Structure end |
#data ⇒ String
The Base64-encoded certificate data required to communicate with
your cluster. Add this to the certificate-authority-data section
of the kubeconfig file for your cluster.
1355 1356 1357 1358 1359 1360 |
# File 'lib/aws-sdk-eks/types.rb', line 1355 class Certificate < Struct.new( :data, :active) SENSITIVE = [] include Aws::Structure end |