Class: Aws::EKS::Types::Certificate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

An object representing the certificate-authority-data for your cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dataString

The Base64-encoded certificate data required to communicate with your cluster. Add this to the certificate-authority-data section of the kubeconfig file for your cluster.

Returns:

  • (String)


1266
1267
1268
1269
1270
# File 'lib/aws-sdk-eks/types.rb', line 1266

class Certificate < Struct.new(
  :data)
  SENSITIVE = []
  include Aws::Structure
end