Class: Aws::EKS::Types::CertificateAuthorityScheduledEvents
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::CertificateAuthorityScheduledEvents
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The scheduled events during which Amazon EKS may automatically activate a certificate authority, computed from its validity period. These events help ensure that a cluster's signing certificate authority is rotated before its certificate expires.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#final_auto_activation ⇒ Time
The Unix epoch timestamp in seconds by which Amazon EKS will automatically activate this certificate authority if you haven't already activated it.
-
#first_auto_activation ⇒ Time
The earliest Unix epoch timestamp in seconds at which Amazon EKS may automatically activate this certificate authority.
Instance Attribute Details
#final_auto_activation ⇒ Time
The Unix epoch timestamp in seconds by which Amazon EKS will automatically activate this certificate authority if you haven't already activated it.
1468 1469 1470 1471 1472 1473 |
# File 'lib/aws-sdk-eks/types.rb', line 1468 class CertificateAuthorityScheduledEvents < Struct.new( :first_auto_activation, :final_auto_activation) SENSITIVE = [] include Aws::Structure end |
#first_auto_activation ⇒ Time
The earliest Unix epoch timestamp in seconds at which Amazon EKS may automatically activate this certificate authority.
1468 1469 1470 1471 1472 1473 |
# File 'lib/aws-sdk-eks/types.rb', line 1468 class CertificateAuthorityScheduledEvents < Struct.new( :first_auto_activation, :final_auto_activation) SENSITIVE = [] include Aws::Structure end |