Class: Aws::EKS::Types::CertificateAuthoritySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::CertificateAuthoritySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Summary information about a certificate authority (CA) for an Amazon
EKS cluster, returned by ListCertificateAuthorities and the
certificate-authority write operations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activated_at ⇒ Time
The Unix epoch timestamp in seconds for when the certificate authority was last activated.
-
#activated_by ⇒ String
The entity that most recently activated the certificate authority, either
CUSTOMERorEKS. -
#created_at ⇒ Time
The Unix epoch timestamp in seconds for when the certificate authority was created.
-
#created_by ⇒ String
The entity that created the certificate authority, either
CUSTOMERorEKS. -
#distribution_status ⇒ String
The distribution status of the certificate authority:
IN_PROGRESS,COMPLETE,FAILED, orDELETING. -
#id ⇒ String
The unique identifier of the certificate authority.
-
#signing_status ⇒ String
The signing status of the certificate authority:
IN_USE,ACTIVATING, orNOT_USED.
Instance Attribute Details
#activated_at ⇒ Time
The Unix epoch timestamp in seconds for when the certificate authority was last activated. This value is absent if the certificate authority has never been activated.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-eks/types.rb', line 1520 class CertificateAuthoritySummary < Struct.new( :id, :created_at, :created_by, :activated_at, :activated_by, :signing_status, :distribution_status) SENSITIVE = [] include Aws::Structure end |
#activated_by ⇒ String
The entity that most recently activated the certificate authority,
either CUSTOMER or EKS.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-eks/types.rb', line 1520 class CertificateAuthoritySummary < Struct.new( :id, :created_at, :created_by, :activated_at, :activated_by, :signing_status, :distribution_status) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The Unix epoch timestamp in seconds for when the certificate authority was created.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-eks/types.rb', line 1520 class CertificateAuthoritySummary < Struct.new( :id, :created_at, :created_by, :activated_at, :activated_by, :signing_status, :distribution_status) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The entity that created the certificate authority, either CUSTOMER
or EKS.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-eks/types.rb', line 1520 class CertificateAuthoritySummary < Struct.new( :id, :created_at, :created_by, :activated_at, :activated_by, :signing_status, :distribution_status) SENSITIVE = [] include Aws::Structure end |
#distribution_status ⇒ String
The distribution status of the certificate authority: IN_PROGRESS,
COMPLETE, FAILED, or DELETING.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-eks/types.rb', line 1520 class CertificateAuthoritySummary < Struct.new( :id, :created_at, :created_by, :activated_at, :activated_by, :signing_status, :distribution_status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the certificate authority.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-eks/types.rb', line 1520 class CertificateAuthoritySummary < Struct.new( :id, :created_at, :created_by, :activated_at, :activated_by, :signing_status, :distribution_status) SENSITIVE = [] include Aws::Structure end |
#signing_status ⇒ String
The signing status of the certificate authority: IN_USE,
ACTIVATING, or NOT_USED.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-eks/types.rb', line 1520 class CertificateAuthoritySummary < Struct.new( :id, :created_at, :created_by, :activated_at, :activated_by, :signing_status, :distribution_status) SENSITIVE = [] include Aws::Structure end |