Class: Aws::EKS::Types::ClientException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

These errors are usually caused by a client action. Actions can include using an action or resource on behalf of an IAM principal that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addon_nameString

The Amazon EKS add-on name associated with the exception.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
# File 'lib/aws-sdk-eks/types.rb', line 1324

class ClientException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The Amazon EKS cluster associated with the exception.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
# File 'lib/aws-sdk-eks/types.rb', line 1324

class ClientException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

These errors are usually caused by a client action. Actions can include using an action or resource on behalf of an IAM principal that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
# File 'lib/aws-sdk-eks/types.rb', line 1324

class ClientException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#nodegroup_nameString

The Amazon EKS managed node group associated with the exception.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
# File 'lib/aws-sdk-eks/types.rb', line 1324

class ClientException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_idString

The Amazon EKS subscription ID with the exception.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
# File 'lib/aws-sdk-eks/types.rb', line 1324

class ClientException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end