Class: Aws::EKS::Types::ClientException
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ClientException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
These errors are usually caused by a client action. Actions can include using an action or resource on behalf of an IAM principal that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#addon_name ⇒ String
The Amazon EKS add-on name associated with the exception.
-
#cluster_name ⇒ String
The Amazon EKS cluster associated with the exception.
-
#message ⇒ String
These errors are usually caused by a client action.
-
#nodegroup_name ⇒ String
The Amazon EKS managed node group associated with the exception.
-
#subscription_id ⇒ String
The Amazon EKS subscription ID with the exception.
Instance Attribute Details
#addon_name ⇒ String
The Amazon EKS add-on name associated with the exception.
1324 1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/aws-sdk-eks/types.rb', line 1324 class ClientException < Struct.new( :cluster_name, :nodegroup_name, :addon_name, :subscription_id, :message) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The Amazon EKS cluster associated with the exception.
1324 1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/aws-sdk-eks/types.rb', line 1324 class ClientException < Struct.new( :cluster_name, :nodegroup_name, :addon_name, :subscription_id, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
These errors are usually caused by a client action. Actions can include using an action or resource on behalf of an IAM principal that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.
1324 1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/aws-sdk-eks/types.rb', line 1324 class ClientException < Struct.new( :cluster_name, :nodegroup_name, :addon_name, :subscription_id, :message) SENSITIVE = [] include Aws::Structure end |
#nodegroup_name ⇒ String
The Amazon EKS managed node group associated with the exception.
1324 1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/aws-sdk-eks/types.rb', line 1324 class ClientException < Struct.new( :cluster_name, :nodegroup_name, :addon_name, :subscription_id, :message) SENSITIVE = [] include Aws::Structure end |
#subscription_id ⇒ String
The Amazon EKS subscription ID with the exception.
1324 1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/aws-sdk-eks/types.rb', line 1324 class ClientException < Struct.new( :cluster_name, :nodegroup_name, :addon_name, :subscription_id, :message) SENSITIVE = [] include Aws::Structure end |