Class: Aws::EKS::Types::ControlPlanePlacementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ControlPlanePlacementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The placement configuration for all the control plane instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see [Capacity considerations] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/eks-outposts-capacity-considerations.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_name ⇒ String
The name of the placement group for the Kubernetes control plane instances.
-
#spread_level ⇒ String
Optional parameter to specify the placement group spread level for control plane instances.
Instance Attribute Details
#group_name ⇒ String
The name of the placement group for the Kubernetes control plane instances. This setting can’t be changed after cluster creation.
1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-eks/types.rb', line 1756 class ControlPlanePlacementRequest < Struct.new( :group_name, :spread_level) SENSITIVE = [] include Aws::Structure end |
#spread_level ⇒ String
Optional parameter to specify the placement group spread level for control plane instances. If not provided, Amazon EKS will deploy control plane instances without a placement group.
1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-eks/types.rb', line 1756 class ControlPlanePlacementRequest < Struct.new( :group_name, :spread_level) SENSITIVE = [] include Aws::Structure end |