Class: Aws::EKS::Types::ControlPlaneScalingTierInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ControlPlaneScalingTierInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Information about a provisioned control plane scaling tier.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#api_request_concurrency ⇒ Integer
The maximum API request concurrency supported by this tier.
-
#cluster_database_size_gb ⇒ Integer
The maximum cluster database size in GB supported by this tier.
-
#control_plane_component_config_overrides ⇒ Types::ControlPlaneConfigInfo
The control plane component configuration overrides specific to this scaling tier.
-
#pod_scheduling_rate_per_second ⇒ Integer
The maximum pod scheduling rate per second supported by this tier.
-
#tier_name ⇒ String
The name of the scaling tier.
Instance Attribute Details
#api_request_concurrency ⇒ Integer
The maximum API request concurrency supported by this tier.
2228 2229 2230 2231 2232 2233 2234 2235 2236 |
# File 'lib/aws-sdk-eks/types.rb', line 2228 class ControlPlaneScalingTierInfo < Struct.new( :tier_name, :api_request_concurrency, :pod_scheduling_rate_per_second, :cluster_database_size_gb, :control_plane_component_config_overrides) SENSITIVE = [] include Aws::Structure end |
#cluster_database_size_gb ⇒ Integer
The maximum cluster database size in GB supported by this tier.
2228 2229 2230 2231 2232 2233 2234 2235 2236 |
# File 'lib/aws-sdk-eks/types.rb', line 2228 class ControlPlaneScalingTierInfo < Struct.new( :tier_name, :api_request_concurrency, :pod_scheduling_rate_per_second, :cluster_database_size_gb, :control_plane_component_config_overrides) SENSITIVE = [] include Aws::Structure end |
#control_plane_component_config_overrides ⇒ Types::ControlPlaneConfigInfo
The control plane component configuration overrides specific to this scaling tier.
2228 2229 2230 2231 2232 2233 2234 2235 2236 |
# File 'lib/aws-sdk-eks/types.rb', line 2228 class ControlPlaneScalingTierInfo < Struct.new( :tier_name, :api_request_concurrency, :pod_scheduling_rate_per_second, :cluster_database_size_gb, :control_plane_component_config_overrides) SENSITIVE = [] include Aws::Structure end |
#pod_scheduling_rate_per_second ⇒ Integer
The maximum pod scheduling rate per second supported by this tier.
2228 2229 2230 2231 2232 2233 2234 2235 2236 |
# File 'lib/aws-sdk-eks/types.rb', line 2228 class ControlPlaneScalingTierInfo < Struct.new( :tier_name, :api_request_concurrency, :pod_scheduling_rate_per_second, :cluster_database_size_gb, :control_plane_component_config_overrides) SENSITIVE = [] include Aws::Structure end |
#tier_name ⇒ String
The name of the scaling tier.
2228 2229 2230 2231 2232 2233 2234 2235 2236 |
# File 'lib/aws-sdk-eks/types.rb', line 2228 class ControlPlaneScalingTierInfo < Struct.new( :tier_name, :api_request_concurrency, :pod_scheduling_rate_per_second, :cluster_database_size_gb, :control_plane_component_config_overrides) SENSITIVE = [] include Aws::Structure end |