Class: Aws::EKS::Types::CreateFargateProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::CreateFargateProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_name ⇒ String
The name of your cluster.
-
#fargate_profile_name ⇒ String
The name of the Fargate profile.
-
#pod_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the
Podexecution role to use for aPodthat matches the selectors in the Fargate profile. -
#selectors ⇒ Array<Types::FargateProfileSelector>
The selectors to match for a
Podto use this Fargate profile. -
#subnets ⇒ Array<String>
The IDs of subnets to launch a
Podinto. -
#tags ⇒ Hash<String,String>
Metadata that assists with categorization and organization.
Instance Attribute Details
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-eks/types.rb', line 1834 class CreateFargateProfileRequest < Struct.new( :fargate_profile_name, :cluster_name, :pod_execution_role_arn, :subnets, :selectors, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of your cluster.
1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-eks/types.rb', line 1834 class CreateFargateProfileRequest < Struct.new( :fargate_profile_name, :cluster_name, :pod_execution_role_arn, :subnets, :selectors, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#fargate_profile_name ⇒ String
The name of the Fargate profile.
1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-eks/types.rb', line 1834 class CreateFargateProfileRequest < Struct.new( :fargate_profile_name, :cluster_name, :pod_execution_role_arn, :subnets, :selectors, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#pod_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Pod execution role to use for a Pod that matches the selectors in the Fargate profile. The Pod execution role allows Fargate infrastructure to register with your cluster as a node, and it provides read access to Amazon ECR image repositories. For more information, see [ Pod execution role] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/pod-execution-role.html
1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-eks/types.rb', line 1834 class CreateFargateProfileRequest < Struct.new( :fargate_profile_name, :cluster_name, :pod_execution_role_arn, :subnets, :selectors, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#selectors ⇒ Array<Types::FargateProfileSelector>
The selectors to match for a Pod to use this Fargate profile. Each selector must have an associated Kubernetes namespace. Optionally, you can also specify labels for a namespace. You may specify up to five selectors in a Fargate profile.
1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-eks/types.rb', line 1834 class CreateFargateProfileRequest < Struct.new( :fargate_profile_name, :cluster_name, :pod_execution_role_arn, :subnets, :selectors, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<String>
The IDs of subnets to launch a Pod into. A Pod running on Fargate isn’t assigned a public IP address, so only private subnets (with no direct route to an Internet Gateway) are accepted for this parameter.
1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-eks/types.rb', line 1834 class CreateFargateProfileRequest < Struct.new( :fargate_profile_name, :cluster_name, :pod_execution_role_arn, :subnets, :selectors, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata that assists with categorization and organization. Each tag consists of a key and an optional value. You define both. Tags don’t propagate to any other cluster or Amazon Web Services resources.
1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-eks/types.rb', line 1834 class CreateFargateProfileRequest < Struct.new( :fargate_profile_name, :cluster_name, :pod_execution_role_arn, :subnets, :selectors, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |