Class: Aws::EKS::Types::DeleteCertificateAuthorityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::DeleteCertificateAuthorityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_authority ⇒ Types::CertificateAuthoritySummary
Summary information about the certificate authority that is being deleted.
-
#update ⇒ Types::Update
An object representing the asynchronous update that removes the certificate authority from the cluster's trust bundle.
Instance Attribute Details
#certificate_authority ⇒ Types::CertificateAuthoritySummary
Summary information about the certificate authority that is being deleted.
3643 3644 3645 3646 3647 3648 |
# File 'lib/aws-sdk-eks/types.rb', line 3643 class DeleteCertificateAuthorityResponse < Struct.new( :update, :certificate_authority) SENSITIVE = [] include Aws::Structure end |
#update ⇒ Types::Update
An object representing the asynchronous update that removes the certificate authority from the cluster's trust bundle.
3643 3644 3645 3646 3647 3648 |
# File 'lib/aws-sdk-eks/types.rb', line 3643 class DeleteCertificateAuthorityResponse < Struct.new( :update, :certificate_authority) SENSITIVE = [] include Aws::Structure end |