Class: Aws::EKS::Types::DescribeAddonConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addon_nameString

The name of the add-on.

Returns:

  • (String)


2529
2530
2531
2532
2533
2534
2535
2536
# File 'lib/aws-sdk-eks/types.rb', line 2529

class DescribeAddonConfigurationResponse < Struct.new(
  :addon_name,
  :addon_version,
  :configuration_schema,
  :pod_identity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#addon_versionString

The version of the add-on. The version must match one of the versions returned by [ DescribeAddonVersions ][1].

[1]: docs.aws.amazon.com/eks/latest/APIReference/API_DescribeAddonVersions.html

Returns:

  • (String)


2529
2530
2531
2532
2533
2534
2535
2536
# File 'lib/aws-sdk-eks/types.rb', line 2529

class DescribeAddonConfigurationResponse < Struct.new(
  :addon_name,
  :addon_version,
  :configuration_schema,
  :pod_identity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_schemaString

A JSON schema that’s used to validate the configuration values you provide when an add-on is created or updated.

Returns:

  • (String)


2529
2530
2531
2532
2533
2534
2535
2536
# File 'lib/aws-sdk-eks/types.rb', line 2529

class DescribeAddonConfigurationResponse < Struct.new(
  :addon_name,
  :addon_version,
  :configuration_schema,
  :pod_identity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pod_identity_configurationArray<Types::AddonPodIdentityConfiguration>

The Kubernetes service account name used by the addon, and any suggested IAM policies. Use this information to create an IAM Role for the Addon.



2529
2530
2531
2532
2533
2534
2535
2536
# File 'lib/aws-sdk-eks/types.rb', line 2529

class DescribeAddonConfigurationResponse < Struct.new(
  :addon_name,
  :addon_version,
  :configuration_schema,
  :pod_identity_configuration)
  SENSITIVE = []
  include Aws::Structure
end