Class: Aws::EKS::Types::DescribeAddonVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::DescribeAddonVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#addons ⇒ Array<Types::AddonInfo>
The list of available versions with Kubernetes version compatibility and other properties.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureDescribeAddonVersionsrequest.
Instance Attribute Details
#addons ⇒ Array<Types::AddonInfo>
The list of available versions with Kubernetes version compatibility and other properties.
4060 4061 4062 4063 4064 4065 |
# File 'lib/aws-sdk-eks/types.rb', line 4060 class DescribeAddonVersionsResponse < Struct.new( :addons, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future DescribeAddonVersions
request. When the results of a DescribeAddonVersions request
exceed maxResults, you can use this value to retrieve the next
page of results. This value is null when there are no more results
to return.
4060 4061 4062 4063 4064 4065 |
# File 'lib/aws-sdk-eks/types.rb', line 4060 class DescribeAddonVersionsResponse < Struct.new( :addons, :next_token) SENSITIVE = [] include Aws::Structure end |