Class: Aws::EKS::Types::EncryptionConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::EncryptionConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The encryption configuration for the cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#provider ⇒ Types::Provider
Key Management Service (KMS) key.
-
#resources ⇒ Array<String>
Amazon EKS encrypts all Kubernetes API data with envelope encryption by default for clusters running Kubernetes version 1.28 or higher, so this field no longer affects which resources are encrypted.
Instance Attribute Details
#provider ⇒ Types::Provider
Key Management Service (KMS) key. Either the ARN or the alias can be used.
4736 4737 4738 4739 4740 4741 |
# File 'lib/aws-sdk-eks/types.rb', line 4736 class EncryptionConfig < Struct.new( :resources, :provider) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<String>
Amazon EKS encrypts all Kubernetes API data with envelope encryption by default for clusters running Kubernetes version 1.28 or higher, so this field no longer affects which resources are encrypted.
Specifies the resources to be encrypted. The only supported value is
secrets.
4736 4737 4738 4739 4740 4741 |
# File 'lib/aws-sdk-eks/types.rb', line 4736 class EncryptionConfig < Struct.new( :resources, :provider) SENSITIVE = [] include Aws::Structure end |