Class: Aws::EKS::Types::EtcdPlacementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The placement configuration for the etcd instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see [Capacity considerations] in the *Amazon EKS User Guide*.

[1]: docs.aws.amazon.com/eks/latest/userguide/eks-outposts-capacity-considerations.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#spread_levelString

Optional parameter to specify the placement group spread level for etcd instances. If not provided, Amazon EKS will deploy etcd instances without a placement group.

Returns:

  • (String)


4204
4205
4206
4207
4208
# File 'lib/aws-sdk-eks/types.rb', line 4204

class EtcdPlacementRequest < Struct.new(
  :spread_level)
  SENSITIVE = []
  include Aws::Structure
end