Class: Aws::EKS::Types::FargateProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::FargateProfile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
An object representing an Fargate profile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
The name of your cluster.
-
#created_at ⇒ Time
The Unix epoch timestamp at object creation.
-
#fargate_profile_arn ⇒ String
The full Amazon Resource Name (ARN) of the Fargate profile.
-
#fargate_profile_name ⇒ String
The name of the Fargate profile.
-
#health ⇒ Types::FargateProfileHealth
The health status of the Fargate profile.
-
#pod_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the ‘Pod` execution role to use for any `Pod` that matches the selectors in the Fargate profile.
-
#selectors ⇒ Array<Types::FargateProfileSelector>
The selectors to match for a ‘Pod` to use this Fargate profile.
-
#status ⇒ String
The current status of the Fargate profile.
-
#subnets ⇒ Array<String>
The IDs of subnets to launch a ‘Pod` into.
-
#tags ⇒ Hash<String,String>
Metadata that assists with categorization and organization.
Instance Attribute Details
#cluster_name ⇒ String
The name of your cluster.
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The Unix epoch timestamp at object creation.
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |
#fargate_profile_arn ⇒ String
The full Amazon Resource Name (ARN) of the Fargate profile.
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |
#fargate_profile_name ⇒ String
The name of the Fargate profile.
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |
#health ⇒ Types::FargateProfileHealth
The health status of the Fargate profile. If there are issues with your Fargate profile’s health, they are listed here.
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |
#pod_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the ‘Pod` execution role to use for any `Pod` that matches the selectors in the Fargate profile. For more information, see [ `Pod` execution role] in the *Amazon EKS User Guide*.
[1]: docs.aws.amazon.com/eks/latest/userguide/pod-execution-role.html
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |
#selectors ⇒ Array<Types::FargateProfileSelector>
The selectors to match for a ‘Pod` to use this Fargate profile.
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Fargate profile.
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<String>
The IDs of subnets to launch a ‘Pod` into.
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Metadata that assists with categorization and organization. Each tag consists of a key and an optional value. You define both. Tags don’t propagate to any other cluster or Amazon Web Services resources.
4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 |
# File 'lib/aws-sdk-eks/types.rb', line 4220 class FargateProfile < Struct.new( :fargate_profile_name, :fargate_profile_arn, :cluster_name, :created_at, :pod_execution_role_arn, :subnets, :selectors, :status, :tags, :health) SENSITIVE = [] include Aws::Structure end |