Class: Aws::EKS::Types::Insight
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::Insight
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
A check that provides recommendations to remedy potential upgrade-impacting issues.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_info ⇒ Hash<String,String>
Links to sources that provide additional context on the insight.
-
#category ⇒ String
The category of the insight.
-
#category_specific_summary ⇒ Types::InsightCategorySpecificSummary
Summary information that relates to the category of the insight.
-
#description ⇒ String
The description of the insight which includes alert criteria, remediation recommendation, and additional resources (contains Markdown).
-
#id ⇒ String
The ID of the insight.
-
#insight_status ⇒ Types::InsightStatus
An object containing more detail on the status of the insight resource.
-
#kubernetes_version ⇒ String
The Kubernetes minor version associated with an insight if applicable.
-
#last_refresh_time ⇒ Time
The time Amazon EKS last successfully completed a refresh of this insight check on the cluster.
-
#last_transition_time ⇒ Time
The time the status of the insight last changed.
-
#name ⇒ String
The name of the insight.
-
#recommendation ⇒ String
A summary of how to remediate the finding of this insight if applicable.
-
#resources ⇒ Array<Types::InsightResourceDetail>
The details about each resource listed in the insight check result.
Instance Attribute Details
#additional_info ⇒ Hash<String,String>
Links to sources that provide additional context on the insight.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
The category of the insight.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#category_specific_summary ⇒ Types::InsightCategorySpecificSummary
Summary information that relates to the category of the insight. Currently only returned with certain insights having category ‘UPGRADE_READINESS`.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the insight which includes alert criteria, remediation recommendation, and additional resources (contains Markdown).
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the insight.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#insight_status ⇒ Types::InsightStatus
An object containing more detail on the status of the insight resource.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#kubernetes_version ⇒ String
The Kubernetes minor version associated with an insight if applicable.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#last_refresh_time ⇒ Time
The time Amazon EKS last successfully completed a refresh of this insight check on the cluster.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#last_transition_time ⇒ Time
The time the status of the insight last changed.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the insight.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#recommendation ⇒ String
A summary of how to remediate the finding of this insight if applicable.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::InsightResourceDetail>
The details about each resource listed in the insight check result.
4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 |
# File 'lib/aws-sdk-eks/types.rb', line 4477 class Insight < Struct.new( :id, :name, :category, :kubernetes_version, :last_refresh_time, :last_transition_time, :description, :insight_status, :recommendation, :additional_info, :resources, :category_specific_summary) SENSITIVE = [] include Aws::Structure end |