Class: Aws::EKS::Types::ListCapabilitiesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ListCapabilitiesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
The name of the Amazon EKS cluster for which you want to list capabilities.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginated request, wheremaxResultswas used and the results exceeded the value of that parameter.
Instance Attribute Details
#cluster_name ⇒ String
The name of the Amazon EKS cluster for which you want to list capabilities.
6215 6216 6217 6218 6219 6220 6221 |
# File 'lib/aws-sdk-eks/types.rb', line 6215 class ListCapabilitiesRequest < Struct.new( :cluster_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. To
retrieve the remaining results, make another call with the returned
nextToken value. If you don't specify a value, the default is 100
results.
6215 6216 6217 6218 6219 6220 6221 |
# File 'lib/aws-sdk-eks/types.rb', line 6215 class ListCapabilitiesRequest < Struct.new( :cluster_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated request,
where maxResults was used and the results exceeded the value of
that parameter. Pagination continues from the end of the previous
results that returned the nextToken value. This value is null when
there are no more results to return.
6215 6216 6217 6218 6219 6220 6221 |
# File 'lib/aws-sdk-eks/types.rb', line 6215 class ListCapabilitiesRequest < Struct.new( :cluster_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |