Class: Aws::EKS::Types::ListFargateProfilesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ListFargateProfilesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fargate_profile_names ⇒ Array<String>
A list of all of the Fargate profiles associated with the specified cluster.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginated request, wheremaxResultswas used and the results exceeded the value of that parameter.
Instance Attribute Details
#fargate_profile_names ⇒ Array<String>
A list of all of the Fargate profiles associated with the specified cluster.
6499 6500 6501 6502 6503 6504 |
# File 'lib/aws-sdk-eks/types.rb', line 6499 class ListFargateProfilesResponse < Struct.new( :fargate_profile_names, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated request,
where maxResults was used and the results exceeded the value of
that parameter. Pagination continues from the end of the previous
results that returned the nextToken value. This value is null when
there are no more results to return.
6499 6500 6501 6502 6503 6504 |
# File 'lib/aws-sdk-eks/types.rb', line 6499 class ListFargateProfilesResponse < Struct.new( :fargate_profile_names, :next_token) SENSITIVE = [] include Aws::Structure end |