Class: Aws::EKS::Types::ListNodegroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ListNodegroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginated request, wheremaxResultswas used and the results exceeded the value of that parameter. -
#nodegroups ⇒ Array<String>
A list of all of the node groups associated with the specified cluster.
Instance Attribute Details
#next_token ⇒ String
The nextToken value returned from a previous paginated request,
where maxResults was used and the results exceeded the value of
that parameter. Pagination continues from the end of the previous
results that returned the nextToken value. This value is null when
there are no more results to return.
6690 6691 6692 6693 6694 6695 |
# File 'lib/aws-sdk-eks/types.rb', line 6690 class ListNodegroupsResponse < Struct.new( :nodegroups, :next_token) SENSITIVE = [] include Aws::Structure end |
#nodegroups ⇒ Array<String>
A list of all of the node groups associated with the specified cluster.
6690 6691 6692 6693 6694 6695 |
# File 'lib/aws-sdk-eks/types.rb', line 6690 class ListNodegroupsResponse < Struct.new( :nodegroups, :next_token) SENSITIVE = [] include Aws::Structure end |