Class: Aws::EKS::Types::ListUpdatesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::ListUpdatesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginated request, wheremaxResultswas used and the results exceeded the value of that parameter. -
#update_ids ⇒ Array<String>
A list of all the updates for the specified cluster and Region.
Instance Attribute Details
#next_token ⇒ String
The nextToken value returned from a previous paginated request,
where maxResults was used and the results exceeded the value of
that parameter. Pagination continues from the end of the previous
results that returned the nextToken value. This value is null when
there are no more results to return.
6890 6891 6892 6893 6894 6895 |
# File 'lib/aws-sdk-eks/types.rb', line 6890 class ListUpdatesResponse < Struct.new( :update_ids, :next_token) SENSITIVE = [] include Aws::Structure end |
#update_ids ⇒ Array<String>
A list of all the updates for the specified cluster and Region.
6890 6891 6892 6893 6894 6895 |
# File 'lib/aws-sdk-eks/types.rb', line 6890 class ListUpdatesResponse < Struct.new( :update_ids, :next_token) SENSITIVE = [] include Aws::Structure end |