Class: Aws::EKS::Types::OutpostConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The configuration of your local Amazon EKS cluster on an Amazon Web Services Outpost. Before creating a cluster on an Outpost, review

Creating a local cluster on an Outpost][1

in the *Amazon EKS User

Guide*. This API isn’t available for Amazon EKS clusters on the Amazon Web Services cloud.

[1]: docs.aws.amazon.com/eks/latest/userguide/eks-outposts-local-cluster-create.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#control_plane_instance_typeString

The Amazon EC2 instance type for the Kubernetes control plane instances of your local Amazon EKS cluster on Amazon Web Services Outposts. This instance type applies to all control plane instances and cannot be changed after cluster creation.

For more information, see [Capacity considerations] in the *Amazon EKS User Guide*.

[1]: docs.aws.amazon.com/eks/latest/userguide/eks-outposts-capacity-considerations.html

Returns:

  • (String)


6695
6696
6697
6698
6699
6700
6701
6702
6703
# File 'lib/aws-sdk-eks/types.rb', line 6695

class OutpostConfigRequest < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end

#control_plane_placementTypes::ControlPlanePlacementRequest

An object representing the placement configuration for all the control plane instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see [Capacity considerations] in the *Amazon EKS User Guide*.

[1]: docs.aws.amazon.com/eks/latest/userguide/eks-outposts-capacity-considerations.html



6695
6696
6697
6698
6699
6700
6701
6702
6703
# File 'lib/aws-sdk-eks/types.rb', line 6695

class OutpostConfigRequest < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end

#etcd_instance_typeString

The Amazon EC2 instance type for etcd instances of your local Amazon EKS cluster on Amazon Web Services Outposts. This instance type applies to all etcd instances and cannot be changed after cluster creation.

Returns:

  • (String)


6695
6696
6697
6698
6699
6700
6701
6702
6703
# File 'lib/aws-sdk-eks/types.rb', line 6695

class OutpostConfigRequest < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end

#etcd_placementTypes::EtcdPlacementRequest

An object representing the placement configuration for the etcd instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see [Capacity considerations] in the *Amazon EKS User Guide*.

[1]: docs.aws.amazon.com/eks/latest/userguide/eks-outposts-capacity-considerations.html



6695
6696
6697
6698
6699
6700
6701
6702
6703
# File 'lib/aws-sdk-eks/types.rb', line 6695

class OutpostConfigRequest < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_arnsArray<String>

The ARN of the Outpost that you want to use for your local Amazon EKS cluster on Outposts. Only a single Outpost ARN is supported.

Returns:

  • (Array<String>)


6695
6696
6697
6698
6699
6700
6701
6702
6703
# File 'lib/aws-sdk-eks/types.rb', line 6695

class OutpostConfigRequest < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end