Class: Aws::EKS::Types::OutpostConfigResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

An object representing the configuration of your local Amazon EKS cluster on an Amazon Web Services Outpost. This API isn’t available for Amazon EKS clusters on the Amazon Web Services cloud.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#control_plane_instance_typeString

The Amazon EC2 instance type for the Kubernetes control plane instances of your local Amazon EKS cluster on Amazon Web Services Outposts. The instance type is the same for all control plane instances.

Returns:

  • (String)


6751
6752
6753
6754
6755
6756
6757
6758
6759
# File 'lib/aws-sdk-eks/types.rb', line 6751

class OutpostConfigResponse < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end

#control_plane_placementTypes::ControlPlanePlacementResponse

An object representing the placement configuration for all the control plane instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see [Capacity considerations] in the *Amazon EKS User Guide*.

[1]: docs.aws.amazon.com/eks/latest/userguide/eks-outposts-capacity-considerations.html



6751
6752
6753
6754
6755
6756
6757
6758
6759
# File 'lib/aws-sdk-eks/types.rb', line 6751

class OutpostConfigResponse < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end

#etcd_instance_typeString

The Amazon EC2 instance type for etcd instances of your local Amazon EKS cluster on Amazon Web Services Outposts. The instance type is the same for all etcd instances.

Returns:

  • (String)


6751
6752
6753
6754
6755
6756
6757
6758
6759
# File 'lib/aws-sdk-eks/types.rb', line 6751

class OutpostConfigResponse < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end

#etcd_placementTypes::EtcdPlacementResponse

An object representing the placement configuration for the etcd instances of your local Amazon EKS cluster on an Amazon Web Services Outpost. For more information, see [Capacity considerations] in the *Amazon EKS User Guide*.

[1]: docs.aws.amazon.com/eks/latest/userguide/eks-outposts-capacity-considerations.html



6751
6752
6753
6754
6755
6756
6757
6758
6759
# File 'lib/aws-sdk-eks/types.rb', line 6751

class OutpostConfigResponse < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_arnsArray<String>

The ARN of the Outpost that you specified for use with your local Amazon EKS cluster on Outposts.

Returns:

  • (Array<String>)


6751
6752
6753
6754
6755
6756
6757
6758
6759
# File 'lib/aws-sdk-eks/types.rb', line 6751

class OutpostConfigResponse < Struct.new(
  :outpost_arns,
  :control_plane_instance_type,
  :control_plane_placement,
  :etcd_instance_type,
  :etcd_placement)
  SENSITIVE = []
  include Aws::Structure
end