Class: Aws::EKS::Types::PodGcControllerConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::PodGcControllerConfigResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
The pod garbage collection controller configuration for the Kubernetes controller manager.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#terminated_pod_gc_threshold ⇒ Integer
The number of terminated pods that can exist before the garbage collector starts deleting them.
Instance Attribute Details
#terminated_pod_gc_threshold ⇒ Integer
The number of terminated pods that can exist before the garbage collector starts deleting them.
7753 7754 7755 7756 7757 |
# File 'lib/aws-sdk-eks/types.rb', line 7753 class PodGcControllerConfigResponse < Struct.new( :terminated_pod_gc_threshold) SENSITIVE = [] include Aws::Structure end |