Class: Aws::EKS::Types::PodIdentityAssociationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The summarized description of the association.

Each summary is simplified by removing these fields compared to the full PodIdentityAssociation :

  • The IAM role: roleArn

  • The timestamp that the association was created at: createdAt

  • The most recent timestamp that the association was modified at:. modifiedAt

  • The tags on the association: tags

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_arnString

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
# File 'lib/aws-sdk-eks/types.rb', line 7424

class PodIdentityAssociationSummary < Struct.new(
  :cluster_name,
  :namespace,
  :service_account,
  :association_arn,
  :association_id,
  :owner_arn)
  SENSITIVE = []
  include Aws::Structure
end

#association_idString

The ID of the association.

Returns:

  • (String)


7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
# File 'lib/aws-sdk-eks/types.rb', line 7424

class PodIdentityAssociationSummary < Struct.new(
  :cluster_name,
  :namespace,
  :service_account,
  :association_arn,
  :association_id,
  :owner_arn)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The name of the cluster that the association is in.

Returns:

  • (String)


7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
# File 'lib/aws-sdk-eks/types.rb', line 7424

class PodIdentityAssociationSummary < Struct.new(
  :cluster_name,
  :namespace,
  :service_account,
  :association_arn,
  :association_id,
  :owner_arn)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The name of the Kubernetes namespace inside the cluster to create the association in. The service account and the Pods that use the service account must be in this namespace.

Returns:

  • (String)


7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
# File 'lib/aws-sdk-eks/types.rb', line 7424

class PodIdentityAssociationSummary < Struct.new(
  :cluster_name,
  :namespace,
  :service_account,
  :association_arn,
  :association_id,
  :owner_arn)
  SENSITIVE = []
  include Aws::Structure
end

#owner_arnString

If defined, the association is owned by an Amazon EKS add-on.

Returns:

  • (String)


7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
# File 'lib/aws-sdk-eks/types.rb', line 7424

class PodIdentityAssociationSummary < Struct.new(
  :cluster_name,
  :namespace,
  :service_account,
  :association_arn,
  :association_id,
  :owner_arn)
  SENSITIVE = []
  include Aws::Structure
end

#service_accountString

The name of the Kubernetes service account inside the cluster to associate the IAM credentials with.

Returns:

  • (String)


7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
# File 'lib/aws-sdk-eks/types.rb', line 7424

class PodIdentityAssociationSummary < Struct.new(
  :cluster_name,
  :namespace,
  :service_account,
  :association_arn,
  :association_id,
  :owner_arn)
  SENSITIVE = []
  include Aws::Structure
end