Class: Aws::EKS::Types::ResourceNotFoundException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

The specified resource could not be found. You can view your available clusters with ListClusters. You can view your available managed node groups with ListNodegroups. Amazon EKS clusters and node groups are Amazon Web Services Region specific.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addon_nameString

The Amazon EKS add-on name associated with the exception.

Returns:

  • (String)


6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
# File 'lib/aws-sdk-eks/types.rb', line 6002

class ResourceNotFoundException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :fargate_profile_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The Amazon EKS cluster associated with the exception.

Returns:

  • (String)


6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
# File 'lib/aws-sdk-eks/types.rb', line 6002

class ResourceNotFoundException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :fargate_profile_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#fargate_profile_nameString

The Fargate profile associated with the exception.

Returns:

  • (String)


6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
# File 'lib/aws-sdk-eks/types.rb', line 6002

class ResourceNotFoundException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :fargate_profile_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The Amazon EKS message associated with the exception.

Returns:

  • (String)


6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
# File 'lib/aws-sdk-eks/types.rb', line 6002

class ResourceNotFoundException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :fargate_profile_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#nodegroup_nameString

The Amazon EKS managed node group associated with the exception.

Returns:

  • (String)


6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
# File 'lib/aws-sdk-eks/types.rb', line 6002

class ResourceNotFoundException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :fargate_profile_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_idString

The Amazon EKS subscription ID with the exception.

Returns:

  • (String)


6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
# File 'lib/aws-sdk-eks/types.rb', line 6002

class ResourceNotFoundException < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :fargate_profile_name,
  :addon_name,
  :subscription_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end