Class: Aws::EKS::Types::StorageConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::StorageConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
Request to update the configuration of the storage capability of your EKS Auto Mode cluster. For example, enable the capability. For more information, see EKS Auto Mode block storage capability in the Amazon EKS User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#block_storage ⇒ Types::BlockStorage
Request to configure EBS Block Storage settings for your EKS Auto Mode cluster.
Instance Attribute Details
#block_storage ⇒ Types::BlockStorage
Request to configure EBS Block Storage settings for your EKS Auto Mode cluster.
8717 8718 8719 8720 8721 |
# File 'lib/aws-sdk-eks/types.rb', line 8717 class StorageConfigRequest < Struct.new( :block_storage) SENSITIVE = [] include Aws::Structure end |