Class: Aws::EKS::Types::Taint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

A property that allows a node to repel a Pod. For more information, see Node taints on managed node groups in the Amazon EKS User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#effectString

The effect of the taint.

Returns:

  • (String)


7677
7678
7679
7680
7681
7682
7683
# File 'lib/aws-sdk-eks/types.rb', line 7677

class Taint < Struct.new(
  :key,
  :value,
  :effect)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The key of the taint.

Returns:

  • (String)


7677
7678
7679
7680
7681
7682
7683
# File 'lib/aws-sdk-eks/types.rb', line 7677

class Taint < Struct.new(
  :key,
  :value,
  :effect)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the taint.

Returns:

  • (String)


7677
7678
7679
7680
7681
7682
7683
# File 'lib/aws-sdk-eks/types.rb', line 7677

class Taint < Struct.new(
  :key,
  :value,
  :effect)
  SENSITIVE = []
  include Aws::Structure
end