Class: Aws::EKS::Types::UnsupportedAvailabilityZoneException
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::UnsupportedAvailabilityZoneException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
At least one of your specified cluster subnets is in an Availability Zone that does not support Amazon EKS. The exception output specifies the supported Availability Zones for your account, from which you can choose subnets for your cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
The Amazon EKS cluster associated with the exception.
-
#message ⇒ String
At least one of your specified cluster subnets is in an Availability Zone that does not support Amazon EKS.
-
#nodegroup_name ⇒ String
The Amazon EKS managed node group associated with the exception.
-
#valid_zones ⇒ Array<String>
The supported Availability Zones for your account.
Instance Attribute Details
#cluster_name ⇒ String
The Amazon EKS cluster associated with the exception.
7539 7540 7541 7542 7543 7544 7545 7546 |
# File 'lib/aws-sdk-eks/types.rb', line 7539 class UnsupportedAvailabilityZoneException < Struct.new( :message, :cluster_name, :nodegroup_name, :valid_zones) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
At least one of your specified cluster subnets is in an Availability Zone that does not support Amazon EKS. The exception output specifies the supported Availability Zones for your account, from which you can choose subnets for your cluster.
7539 7540 7541 7542 7543 7544 7545 7546 |
# File 'lib/aws-sdk-eks/types.rb', line 7539 class UnsupportedAvailabilityZoneException < Struct.new( :message, :cluster_name, :nodegroup_name, :valid_zones) SENSITIVE = [] include Aws::Structure end |
#nodegroup_name ⇒ String
The Amazon EKS managed node group associated with the exception.
7539 7540 7541 7542 7543 7544 7545 7546 |
# File 'lib/aws-sdk-eks/types.rb', line 7539 class UnsupportedAvailabilityZoneException < Struct.new( :message, :cluster_name, :nodegroup_name, :valid_zones) SENSITIVE = [] include Aws::Structure end |
#valid_zones ⇒ Array<String>
The supported Availability Zones for your account. Choose subnets in these Availability Zones for your cluster.
7539 7540 7541 7542 7543 7544 7545 7546 |
# File 'lib/aws-sdk-eks/types.rb', line 7539 class UnsupportedAvailabilityZoneException < Struct.new( :message, :cluster_name, :nodegroup_name, :valid_zones) SENSITIVE = [] include Aws::Structure end |