Class: Aws::EKS::Types::Update
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKS::Types::Update
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eks/types.rb
Overview
An object representing an asynchronous update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cancellation ⇒ Types::Cancellation
The latest cancellation information for the update.
-
#created_at ⇒ Time
The Unix epoch timestamp at object creation.
-
#errors ⇒ Array<Types::ErrorDetail>
Any errors associated with a
Failedupdate. -
#id ⇒ String
A UUID that is used to track the update.
-
#params ⇒ Array<Types::UpdateParam>
A key-value map that contains the parameters associated with the update.
-
#status ⇒ String
The current status of the update.
-
#type ⇒ String
The type of the update.
Instance Attribute Details
#cancellation ⇒ Types::Cancellation
The latest cancellation information for the update. This field is present only if any cancellation is attempted for the update.
8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 |
# File 'lib/aws-sdk-eks/types.rb', line 8803 class Update < Struct.new( :id, :status, :type, :params, :created_at, :errors, :cancellation) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The Unix epoch timestamp at object creation.
8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 |
# File 'lib/aws-sdk-eks/types.rb', line 8803 class Update < Struct.new( :id, :status, :type, :params, :created_at, :errors, :cancellation) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::ErrorDetail>
Any errors associated with a Failed update.
8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 |
# File 'lib/aws-sdk-eks/types.rb', line 8803 class Update < Struct.new( :id, :status, :type, :params, :created_at, :errors, :cancellation) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A UUID that is used to track the update.
8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 |
# File 'lib/aws-sdk-eks/types.rb', line 8803 class Update < Struct.new( :id, :status, :type, :params, :created_at, :errors, :cancellation) SENSITIVE = [] include Aws::Structure end |
#params ⇒ Array<Types::UpdateParam>
A key-value map that contains the parameters associated with the update.
8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 |
# File 'lib/aws-sdk-eks/types.rb', line 8803 class Update < Struct.new( :id, :status, :type, :params, :created_at, :errors, :cancellation) SENSITIVE = [] include Aws::Structure end |