Class: Aws::EKS::Types::UpdateNodegroupConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eks/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
# File 'lib/aws-sdk-eks/types.rb', line 8226

class UpdateNodegroupConfigRequest < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :labels,
  :taints,
  :scaling_config,
  :update_config,
  :node_repair_config,
  :warm_pool_config,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The name of your cluster.

Returns:

  • (String)


8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
# File 'lib/aws-sdk-eks/types.rb', line 8226

class UpdateNodegroupConfigRequest < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :labels,
  :taints,
  :scaling_config,
  :update_config,
  :node_repair_config,
  :warm_pool_config,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#labelsTypes::UpdateLabelsPayload

The Kubernetes ‘labels` to apply to the nodes in the node group after the update.



8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
# File 'lib/aws-sdk-eks/types.rb', line 8226

class UpdateNodegroupConfigRequest < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :labels,
  :taints,
  :scaling_config,
  :update_config,
  :node_repair_config,
  :warm_pool_config,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#node_repair_configTypes::NodeRepairConfig

The node auto repair configuration for the node group.



8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
# File 'lib/aws-sdk-eks/types.rb', line 8226

class UpdateNodegroupConfigRequest < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :labels,
  :taints,
  :scaling_config,
  :update_config,
  :node_repair_config,
  :warm_pool_config,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#nodegroup_nameString

The name of the managed node group to update.

Returns:

  • (String)


8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
# File 'lib/aws-sdk-eks/types.rb', line 8226

class UpdateNodegroupConfigRequest < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :labels,
  :taints,
  :scaling_config,
  :update_config,
  :node_repair_config,
  :warm_pool_config,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_configTypes::NodegroupScalingConfig

The scaling configuration details for the Auto Scaling group after the update.



8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
# File 'lib/aws-sdk-eks/types.rb', line 8226

class UpdateNodegroupConfigRequest < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :labels,
  :taints,
  :scaling_config,
  :update_config,
  :node_repair_config,
  :warm_pool_config,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#taintsTypes::UpdateTaintsPayload

The Kubernetes taints to be applied to the nodes in the node group after the update. For more information, see [Node taints on managed node groups].

[1]: docs.aws.amazon.com/eks/latest/userguide/node-taints-managed-node-groups.html



8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
# File 'lib/aws-sdk-eks/types.rb', line 8226

class UpdateNodegroupConfigRequest < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :labels,
  :taints,
  :scaling_config,
  :update_config,
  :node_repair_config,
  :warm_pool_config,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#update_configTypes::NodegroupUpdateConfig

The node group update configuration.



8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
# File 'lib/aws-sdk-eks/types.rb', line 8226

class UpdateNodegroupConfigRequest < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :labels,
  :taints,
  :scaling_config,
  :update_config,
  :node_repair_config,
  :warm_pool_config,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#warm_pool_configTypes::WarmPoolConfig

The warm pool configuration to apply to the node group. You can use this to add a warm pool to an existing node group or modify the settings of an existing warm pool.



8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
# File 'lib/aws-sdk-eks/types.rb', line 8226

class UpdateNodegroupConfigRequest < Struct.new(
  :cluster_name,
  :nodegroup_name,
  :labels,
  :taints,
  :scaling_config,
  :update_config,
  :node_repair_config,
  :warm_pool_config,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end